Module: Smplkit::ApiSupport Private

Defined in:
lib/smplkit/api_support.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Ruby-internal adapters bridging the generated client layer to the wrapper.

Defined Under Namespace

Modules: ErrorMapping, PaginatedFetch, ResourceShim

Constant Summary collapse

RUNTIME_PAGE_SIZE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Default page the runtime asks for when walking a list endpoint to completion. The platform caps page at 1000; using the same value here makes the minimum number of round-trips per exhaustive fetch.

1000