Class: Smplkit::Flags::FlagStats
- Inherits:
-
Struct
- Object
- Struct
- Smplkit::Flags::FlagStats
- Defined in:
- lib/smplkit/flags/client.rb
Overview
Evaluation statistics for the flags runtime.
Instance Attribute Summary collapse
-
#cache_hits ⇒ Integer
readonly
Number of flag evaluations served from the local cache.
-
#cache_misses ⇒ Integer
readonly
Number of flag evaluations that missed the cache and were evaluated from the flag definitions.
Instance Attribute Details
#cache_hits ⇒ Integer (readonly)
Returns number of flag evaluations served from the local cache.
115 |
# File 'lib/smplkit/flags/client.rb', line 115 FlagStats = Struct.new(:cache_hits, :cache_misses, keyword_init: true) |
#cache_misses ⇒ Integer (readonly)
Returns number of flag evaluations that missed the cache and were evaluated from the flag definitions.
115 |
# File 'lib/smplkit/flags/client.rb', line 115 FlagStats = Struct.new(:cache_hits, :cache_misses, keyword_init: true) |