Exception: Smplkit::PaymentRequiredError
- Defined in:
- lib/smplkit/errors.rb
Overview
Raised when the server rejects a request because the account’s subscription plan does not include the required entitlement.
Instance Attribute Summary
Attributes inherited from Error
Method Summary
Methods inherited from Error
derive_message, #initialize, #to_s
Constructor Details
This class inherits a constructor from Smplkit::Error