Class: SmplkitGeneratedClient::App::AddPaymentMethodAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::AddPaymentMethodAttributes
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb
Overview
Attributes accepted when registering a new payment method. The customer first creates a Stripe payment method client-side using Stripe Elements, then submits its pm_... identifier here to persist it on the account.
Instance Attribute Summary collapse
-
#default ⇒ Object
When
true, make the newly registered payment method the account's default. -
#stripe_payment_method_id ⇒ Object
Identifier of the Stripe payment method to register on the account, e.g.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddPaymentMethodAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddPaymentMethodAttributes
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::AddPaymentMethodAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::AddPaymentMethodAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'stripe_payment_method_id') self.stripe_payment_method_id = attributes[:'stripe_payment_method_id'] else self.stripe_payment_method_id = nil end if attributes.key?(:'default') self.default = attributes[:'default'] else self.default = false end end |
Instance Attribute Details
#default ⇒ Object
When true, make the newly registered payment method the account's default. The first payment method on an account is always set as default regardless of this field.
23 24 25 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 23 def default @default end |
#stripe_payment_method_id ⇒ Object
Identifier of the Stripe payment method to register on the account, e.g. pm_1234567890abcdef.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 20 def stripe_payment_method_id @stripe_payment_method_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 26 def self.attribute_map { :'stripe_payment_method_id' => :'stripe_payment_method_id', :'default' => :'default' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 44 def self.openapi_types { :'stripe_payment_method_id' => :'String', :'default' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && stripe_payment_method_id == o.stripe_payment_method_id && default == o.default end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 142 def hash [stripe_payment_method_id, default].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @stripe_payment_method_id.nil? invalid_properties.push('invalid value for "stripe_payment_method_id", stripe_payment_method_id cannot be nil.') end if @stripe_payment_method_id.to_s.length < 1 invalid_properties.push('invalid value for "stripe_payment_method_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
104 105 106 107 108 109 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/add_payment_method_attributes.rb', line 104 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @stripe_payment_method_id.nil? return false if @stripe_payment_method_id.to_s.length < 1 true end |