Class: SmplkitGeneratedClient::App::ContextType
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::ContextType
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Known attribute keys with metadata objects.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#name ⇒ Object
Display label: User, Account, Device.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContextType
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ContextType
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::ContextType` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::ContextType`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'attributes') if (value = attributes[:'attributes']).is_a?(Hash) self.attributes = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#attributes ⇒ Object
Known attribute keys with metadata objects
22 23 24 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 22 def attributes @attributes end |
#created_at ⇒ Object
Returns the value of attribute created_at.
24 25 26 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 24 def created_at @created_at end |
#name ⇒ Object
Display label: User, Account, Device
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 19 def name @name end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 26 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 29 def self.attribute_map { :'name' => :'name', :'attributes' => :'attributes', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 63 64 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 59 def self.openapi_nullable Set.new([ :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 49 def self.openapi_types { :'name' => :'String', :'attributes' => :'Hash<String, Object>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && attributes == o.attributes && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 152 def hash [name, attributes, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/context_type.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? true end |