Class: SmplkitGeneratedClient::App::ContextTypesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ContextTypesApi

Returns a new instance of ContextTypesApi.



19
20
21
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_context_type(context_type_response, opts = {}) ⇒ ContextTypeResponse

Create Context Type Create a new context type. The caller provides the id (key) in the request body.

Parameters:

  • context_type_response (ContextTypeResponse)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 27

def create_context_type(context_type_response, opts = {})
  data, _status_code, _headers = create_context_type_with_http_info(context_type_response, opts)
  data
end

#create_context_type_with_http_info(context_type_response, opts = {}) ⇒ Array<(ContextTypeResponse, Integer, Hash)>

Create Context Type Create a new context type. The caller provides the id (key) in the request body.

Parameters:

  • context_type_response (ContextTypeResponse)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ContextTypeResponse, Integer, Hash)>)

    ContextTypeResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 37

def create_context_type_with_http_info(context_type_response, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContextTypesApi.create_context_type ...'
  end
  # verify the required parameter 'context_type_response' is set
  if @api_client.config.client_side_validation && context_type_response.nil?
    fail ArgumentError, "Missing the required parameter 'context_type_response' when calling ContextTypesApi.create_context_type"
  end
  # resource path
  local_var_path = '/api/v1/context_types'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/vnd.api+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(context_type_response)

  # return_type
  return_type = opts[:debug_return_type] || 'ContextTypeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"ContextTypesApi.create_context_type",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContextTypesApi#create_context_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_context_type(id, opts = {}) ⇒ nil

Delete Context Type Delete a context type and all its associated context instances by id.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


95
96
97
98
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 95

def delete_context_type(id, opts = {})
  delete_context_type_with_http_info(id, opts)
  nil
end

#delete_context_type_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Context Type Delete a context type and all its associated context instances by id.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 105

def delete_context_type_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContextTypesApi.delete_context_type ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ContextTypesApi.delete_context_type"
  end
  # resource path
  local_var_path = '/api/v1/context_types/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"ContextTypesApi.delete_context_type",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContextTypesApi#delete_context_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_context_type(id, opts = {}) ⇒ ContextTypeResponse

Get Context Type Return a context type by id.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



158
159
160
161
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 158

def get_context_type(id, opts = {})
  data, _status_code, _headers = get_context_type_with_http_info(id, opts)
  data
end

#get_context_type_with_http_info(id, opts = {}) ⇒ Array<(ContextTypeResponse, Integer, Hash)>

Get Context Type Return a context type by id.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ContextTypeResponse, Integer, Hash)>)

    ContextTypeResponse data, response status code and response headers



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 168

def get_context_type_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContextTypesApi.get_context_type ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ContextTypesApi.get_context_type"
  end
  # resource path
  local_var_path = '/api/v1/context_types/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ContextTypeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"ContextTypesApi.get_context_type",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContextTypesApi#get_context_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_context_types(opts = {}) ⇒ ContextTypeListResponse

List Context Types List all context types for the authenticated account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



220
221
222
223
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 220

def list_context_types(opts = {})
  data, _status_code, _headers = list_context_types_with_http_info(opts)
  data
end

#list_context_types_with_http_info(opts = {}) ⇒ Array<(ContextTypeListResponse, Integer, Hash)>

List Context Types List all context types for the authenticated account.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ContextTypeListResponse, Integer, Hash)>)

    ContextTypeListResponse data, response status code and response headers



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 229

def list_context_types_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContextTypesApi.list_context_types ...'
  end
  # resource path
  local_var_path = '/api/v1/context_types'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ContextTypeListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"ContextTypesApi.list_context_types",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContextTypesApi#list_context_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_context_type(id, context_type_response, opts = {}) ⇒ ContextTypeResponse

Update Context Type Update a context type by id.

Parameters:

  • id (String)
  • context_type_response (ContextTypeResponse)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



279
280
281
282
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 279

def update_context_type(id, context_type_response, opts = {})
  data, _status_code, _headers = update_context_type_with_http_info(id, context_type_response, opts)
  data
end

#update_context_type_with_http_info(id, context_type_response, opts = {}) ⇒ Array<(ContextTypeResponse, Integer, Hash)>

Update Context Type Update a context type by id.

Parameters:

  • id (String)
  • context_type_response (ContextTypeResponse)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ContextTypeResponse, Integer, Hash)>)

    ContextTypeResponse data, response status code and response headers



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/context_types_api.rb', line 290

def update_context_type_with_http_info(id, context_type_response, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ContextTypesApi.update_context_type ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling ContextTypesApi.update_context_type"
  end
  # verify the required parameter 'context_type_response' is set
  if @api_client.config.client_side_validation && context_type_response.nil?
    fail ArgumentError, "Missing the required parameter 'context_type_response' when calling ContextTypesApi.update_context_type"
  end
  # resource path
  local_var_path = '/api/v1/context_types/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/vnd.api+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(context_type_response)

  # return_type
  return_type = opts[:debug_return_type] || 'ContextTypeResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['HTTPBearer']

  new_options = opts.merge(
    :operation => :"ContextTypesApi.update_context_type",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ContextTypesApi#update_context_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end