Class: SmplkitGeneratedClient::App::ContextsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::ContextsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bulk_register_contexts(context_bulk_register, opts = {}) ⇒ ContextBatchResponse
Bulk Register Contexts Register context instances in bulk.
-
#bulk_register_contexts_with_http_info(context_bulk_register, opts = {}) ⇒ Array<(ContextBatchResponse, Integer, Hash)>
Bulk Register Contexts Register context instances in bulk.
-
#delete_context(id, opts = {}) ⇒ nil
Delete Context Delete a context instance by composite id (type:key).
-
#delete_context_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Context Delete a context instance by composite id (type:key).
-
#get_context(id, opts = {}) ⇒ ContextResponse
Get Context Return a context instance by composite id (type:key).
-
#get_context_with_http_info(id, opts = {}) ⇒ Array<(ContextResponse, Integer, Hash)>
Get Context Return a context instance by composite id (type:key).
-
#initialize(api_client = ApiClient.default) ⇒ ContextsApi
constructor
A new instance of ContextsApi.
-
#list_contexts(opts = {}) ⇒ ContextListResponse
List Contexts List all context instances for the authenticated account.
-
#list_contexts_with_http_info(opts = {}) ⇒ Array<(ContextListResponse, Integer, Hash)>
List Contexts List all context instances for the authenticated account.
-
#update_context(id, context_response, opts = {}) ⇒ ContextResponse
Update Context Update a context instance by composite id (type:key).
-
#update_context_with_http_info(id, context_response, opts = {}) ⇒ Array<(ContextResponse, Integer, Hash)>
Update Context Update a context instance by composite id (type:key).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContextsApi
Returns a new instance of ContextsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bulk_register_contexts(context_bulk_register, opts = {}) ⇒ ContextBatchResponse
Bulk Register Contexts Register context instances in bulk. Creates context types automatically if they don’t exist.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 27 def bulk_register_contexts(context_bulk_register, opts = {}) data, _status_code, _headers = bulk_register_contexts_with_http_info(context_bulk_register, opts) data end |
#bulk_register_contexts_with_http_info(context_bulk_register, opts = {}) ⇒ Array<(ContextBatchResponse, Integer, Hash)>
Bulk Register Contexts Register context instances in bulk. Creates context types automatically if they don't exist.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 37 def bulk_register_contexts_with_http_info(context_bulk_register, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsApi.bulk_register_contexts ...' end # verify the required parameter 'context_bulk_register' is set if @api_client.config.client_side_validation && context_bulk_register.nil? fail ArgumentError, "Missing the required parameter 'context_bulk_register' when calling ContextsApi.bulk_register_contexts" end # resource path local_var_path = '/api/v1/contexts/bulk' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(context_bulk_register) # return_type return_type = opts[:debug_return_type] || 'ContextBatchResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ContextsApi.bulk_register_contexts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsApi#bulk_register_contexts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_context(id, opts = {}) ⇒ nil
Delete Context Delete a context instance by composite id (type:key).
95 96 97 98 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 95 def delete_context(id, opts = {}) delete_context_with_http_info(id, opts) nil end |
#delete_context_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Context Delete a context instance by composite id (type:key).
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 105 def delete_context_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsApi.delete_context ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContextsApi.delete_context" end # resource path local_var_path = '/api/v1/contexts/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ContextsApi.delete_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsApi#delete_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_context(id, opts = {}) ⇒ ContextResponse
Get Context Return a context instance by composite id (type:key).
158 159 160 161 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 158 def get_context(id, opts = {}) data, _status_code, _headers = get_context_with_http_info(id, opts) data end |
#get_context_with_http_info(id, opts = {}) ⇒ Array<(ContextResponse, Integer, Hash)>
Get Context Return a context instance by composite id (type:key).
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 168 def get_context_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsApi.get_context ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContextsApi.get_context" end # resource path local_var_path = '/api/v1/contexts/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContextResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ContextsApi.get_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsApi#get_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_contexts(opts = {}) ⇒ ContextListResponse
List Contexts List all context instances for the authenticated account.
221 222 223 224 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 221 def list_contexts(opts = {}) data, _status_code, _headers = list_contexts_with_http_info(opts) data end |
#list_contexts_with_http_info(opts = {}) ⇒ Array<(ContextListResponse, Integer, Hash)>
List Contexts List all context instances for the authenticated account.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 231 def list_contexts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsApi.list_contexts ...' end # resource path local_var_path = '/api/v1/contexts' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[context_type]'] = opts[:'filter_context_type'] if !opts[:'filter_context_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContextListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ContextsApi.list_contexts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsApi#list_contexts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_context(id, context_response, opts = {}) ⇒ ContextResponse
Update Context Update a context instance by composite id (type:key). Only the human-readable display name is mutable through this endpoint; context_type and observed attributes are written by the SDK ingestion path.
282 283 284 285 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 282 def update_context(id, context_response, opts = {}) data, _status_code, _headers = update_context_with_http_info(id, context_response, opts) data end |
#update_context_with_http_info(id, context_response, opts = {}) ⇒ Array<(ContextResponse, Integer, Hash)>
Update Context Update a context instance by composite id (type:key). Only the human-readable display name is mutable through this endpoint; context_type and observed attributes are written by the SDK ingestion path.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/contexts_api.rb', line 293 def update_context_with_http_info(id, context_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsApi.update_context ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContextsApi.update_context" end # verify the required parameter 'context_response' is set if @api_client.config.client_side_validation && context_response.nil? fail ArgumentError, "Missing the required parameter 'context_response' when calling ContextsApi.update_context" end # resource path local_var_path = '/api/v1/contexts/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(context_response) # return_type return_type = opts[:debug_return_type] || 'ContextResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ContextsApi.update_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsApi#update_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |