Class: SmplkitGeneratedClient::App::CreateSubscriptionAttributes

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb

Overview

Attributes accepted when creating a new subscription.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateSubscriptionAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::CreateSubscriptionAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::CreateSubscriptionAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  else
    self.product = nil
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  else
    self.plan = nil
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end
end

Instance Attribute Details

#payment_methodObject

UUID of a payment method on file to bill against. If omitted, the account’s default payment method is used.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 26

def payment_method
  @payment_method
end

#planObject

Plan key to subscribe on, e.g. ‘pro`.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 23

def plan
  @plan
end

#productObject

Product key to subscribe to, e.g. ‘flags`.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 20

def product
  @product
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 29

def self.attribute_map
  {
    :'product' => :'product',
    :'plan' => :'plan',
    :'payment_method' => :'payment_method'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 166

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 57

def self.openapi_nullable
  Set.new([
    :'payment_method'
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 48

def self.openapi_types
  {
    :'product' => :'String',
    :'plan' => :'String',
    :'payment_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      product == o.product &&
      plan == o.plan &&
      payment_method == o.payment_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 153

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



159
160
161
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 159

def hash
  [product, plan, payment_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 98

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @product.nil?
    invalid_properties.push('invalid value for "product", product cannot be nil.')
  end

  if @plan.nil?
    invalid_properties.push('invalid value for "plan", plan cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
117
118
119
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/create_subscription_attributes.rb', line 114

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @product.nil?
  return false if @plan.nil?
  true
end