Class: SmplkitGeneratedClient::App::Email

Inherits:
ApiModelBase show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb

Overview

Contact-us email resource attributes. This resource is a pure action — it is not persisted. The id returned in the response is a per-request uuid4 for correlation only.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Email

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::Email` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::Email`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'topic')
    self.topic = attributes[:'topic']
  else
    self.topic = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  else
    self.body = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



21
22
23
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 21

def body
  @body
end

#sent_atObject

Returns the value of attribute sent_at.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 23

def sent_at
  @sent_at
end

#topicObject

Returns the value of attribute topic.



19
20
21
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 19

def topic
  @topic
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 48

def self.attribute_map
  {
    :'topic' => :'topic',
    :'body' => :'body',
    :'sent_at' => :'sent_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 203

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 76

def self.openapi_nullable
  Set.new([
    :'sent_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 67

def self.openapi_types
  {
    :'topic' => :'ContactTopic',
    :'body' => :'String',
    :'sent_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      topic == o.topic &&
      body == o.body &&
      sent_at == o.sent_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 196

def hash
  [topic, body, sent_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @topic.nil?
    invalid_properties.push('invalid value for "topic", topic cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @body.to_s.length > 10000
    invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 10000.')
  end

  if @body.to_s.length < 1
    invalid_properties.push('invalid value for "body", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/email.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @topic.nil?
  return false if @body.nil?
  return false if @body.to_s.length > 10000
  return false if @body.to_s.length < 1
  true
end