Class: SmplkitGeneratedClient::App::EmailRegistrationsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::EmailRegistrationsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/email_registrations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_email_registration(request_body, opts = {}) ⇒ nil
Register for Launch List Submit an email address to the smplkit launch list.
-
#create_email_registration_with_http_info(request_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Register for Launch List Submit an email address to the smplkit launch list.
-
#initialize(api_client = ApiClient.default) ⇒ EmailRegistrationsApi
constructor
A new instance of EmailRegistrationsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EmailRegistrationsApi
Returns a new instance of EmailRegistrationsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/email_registrations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/email_registrations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_email_registration(request_body, opts = {}) ⇒ nil
Register for Launch List Submit an email address to the smplkit launch list. Sends a notification to support@smplkit.com. No authentication required. Nothing is persisted.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/email_registrations_api.rb', line 27 def create_email_registration(request_body, opts = {}) create_email_registration_with_http_info(request_body, opts) nil end |
#create_email_registration_with_http_info(request_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Register for Launch List Submit an email address to the smplkit launch list. Sends a notification to support@smplkit.com. No authentication required. Nothing is persisted.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/email_registrations_api.rb', line 37 def create_email_registration_with_http_info(request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EmailRegistrationsApi.create_email_registration ...' end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling EmailRegistrationsApi.create_email_registration" end # resource path local_var_path = '/api/v1/email-registrations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"EmailRegistrationsApi.create_email_registration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EmailRegistrationsApi#create_email_registration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |