Class: SmplkitGeneratedClient::App::EnvironmentsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::EnvironmentsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_environment(environment_request, opts = {}) ⇒ EnvironmentResponse
Create Environment Create a new environment.
-
#create_environment_with_http_info(environment_request, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Create Environment Create a new environment.
-
#delete_environment(id, opts = {}) ⇒ nil
Delete Environment Delete an environment by id.
-
#delete_environment_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Environment Delete an environment by id.
-
#get_environment(id, opts = {}) ⇒ EnvironmentResponse
Get Environment Return an environment by id.
-
#get_environment_usage(id, opts = {}) ⇒ EnvironmentUsageResponse
Report Environment Usage Report how many flag rules, env-level flag defaults, config overrides, and logger overrides reference this environment.
-
#get_environment_usage_with_http_info(id, opts = {}) ⇒ Array<(EnvironmentUsageResponse, Integer, Hash)>
Report Environment Usage Report how many flag rules, env-level flag defaults, config overrides, and logger overrides reference this environment.
-
#get_environment_with_http_info(id, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Get Environment Return an environment by id.
-
#initialize(api_client = ApiClient.default) ⇒ EnvironmentsApi
constructor
A new instance of EnvironmentsApi.
-
#list_environments(opts = {}) ⇒ EnvironmentListResponse
List Environments List all environments for the authenticated account.
-
#list_environments_with_http_info(opts = {}) ⇒ Array<(EnvironmentListResponse, Integer, Hash)>
List Environments List all environments for the authenticated account.
-
#update_environment(id, environment_request, opts = {}) ⇒ EnvironmentResponse
Update Environment Update an environment by id.
-
#update_environment_with_http_info(id, environment_request, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Update Environment Update an environment by id.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EnvironmentsApi
Returns a new instance of EnvironmentsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_environment(environment_request, opts = {}) ⇒ EnvironmentResponse
Create Environment Create a new environment. The caller provides the id (key) in the request body.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 27 def create_environment(environment_request, opts = {}) data, _status_code, _headers = create_environment_with_http_info(environment_request, opts) data end |
#create_environment_with_http_info(environment_request, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Create Environment Create a new environment. The caller provides the id (key) in the request body.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 37 def create_environment_with_http_info(environment_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.create_environment ...' end # verify the required parameter 'environment_request' is set if @api_client.config.client_side_validation && environment_request.nil? fail ArgumentError, "Missing the required parameter 'environment_request' when calling EnvironmentsApi.create_environment" end # resource path local_var_path = '/api/v1/environments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(environment_request) # return_type return_type = opts[:debug_return_type] || 'EnvironmentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.create_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#create_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_environment(id, opts = {}) ⇒ nil
Delete Environment Delete an environment by id. When ‘cascade=true` is set, also remove every per-environment reference held by flags, configs, and loggers in the corresponding services before deleting the environment row. The default `cascade=false` deletes only the environment row, leaving downstream references in place.
96 97 98 99 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 96 def delete_environment(id, opts = {}) delete_environment_with_http_info(id, opts) nil end |
#delete_environment_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Environment Delete an environment by id. When `cascade=true` is set, also remove every per-environment reference held by flags, configs, and loggers in the corresponding services before deleting the environment row. The default `cascade=false` deletes only the environment row, leaving downstream references in place.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 107 def delete_environment_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.delete_environment ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EnvironmentsApi.delete_environment" end # resource path local_var_path = '/api/v1/environments/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'cascade'] = opts[:'cascade'] if !opts[:'cascade'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.delete_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#delete_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_environment(id, opts = {}) ⇒ EnvironmentResponse
Get Environment Return an environment by id.
161 162 163 164 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 161 def get_environment(id, opts = {}) data, _status_code, _headers = get_environment_with_http_info(id, opts) data end |
#get_environment_usage(id, opts = {}) ⇒ EnvironmentUsageResponse
Report Environment Usage Report how many flag rules, env-level flag defaults, config overrides, and logger overrides reference this environment. Used by the console’s delete dialog so the user can see what would survive a non-cascading delete.
224 225 226 227 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 224 def get_environment_usage(id, opts = {}) data, _status_code, _headers = get_environment_usage_with_http_info(id, opts) data end |
#get_environment_usage_with_http_info(id, opts = {}) ⇒ Array<(EnvironmentUsageResponse, Integer, Hash)>
Report Environment Usage Report how many flag rules, env-level flag defaults, config overrides, and logger overrides reference this environment. Used by the console's delete dialog so the user can see what would survive a non-cascading delete.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 234 def get_environment_usage_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.get_environment_usage ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EnvironmentsApi.get_environment_usage" end # resource path local_var_path = '/api/v1/environments/{id}/usage'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EnvironmentUsageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.get_environment_usage", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#get_environment_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_environment_with_http_info(id, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Get Environment Return an environment by id.
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 171 def get_environment_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.get_environment ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EnvironmentsApi.get_environment" end # resource path local_var_path = '/api/v1/environments/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EnvironmentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.get_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#get_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_environments(opts = {}) ⇒ EnvironmentListResponse
List Environments List all environments for the authenticated account.
286 287 288 289 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 286 def list_environments(opts = {}) data, _status_code, _headers = list_environments_with_http_info(opts) data end |
#list_environments_with_http_info(opts = {}) ⇒ Array<(EnvironmentListResponse, Integer, Hash)>
List Environments List all environments for the authenticated account.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 295 def list_environments_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.list_environments ...' end # resource path local_var_path = '/api/v1/environments' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EnvironmentListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.list_environments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#list_environments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_environment(id, environment_request, opts = {}) ⇒ EnvironmentResponse
Update Environment Update an environment by id.
345 346 347 348 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 345 def update_environment(id, environment_request, opts = {}) data, _status_code, _headers = update_environment_with_http_info(id, environment_request, opts) data end |
#update_environment_with_http_info(id, environment_request, opts = {}) ⇒ Array<(EnvironmentResponse, Integer, Hash)>
Update Environment Update an environment by id.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/environments_api.rb', line 356 def update_environment_with_http_info(id, environment_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EnvironmentsApi.update_environment ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EnvironmentsApi.update_environment" end # verify the required parameter 'environment_request' is set if @api_client.config.client_side_validation && environment_request.nil? fail ArgumentError, "Missing the required parameter 'environment_request' when calling EnvironmentsApi.update_environment" end # resource path local_var_path = '/api/v1/environments/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(environment_request) # return_type return_type = opts[:debug_return_type] || 'EnvironmentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EnvironmentsApi.update_environment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EnvironmentsApi#update_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |