Class: SmplkitGeneratedClient::App::MetricRollupAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::MetricRollupAttributes
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb
Overview
An aggregated metric value over a fixed-size time bucket.
Instance Attribute Summary collapse
-
#bucket ⇒ Object
Start of the time bucket this rollup covers.
-
#name ⇒ Object
Metric series name the rollup is computed from.
-
#rollup ⇒ Object
Rollup interval.
-
#unit ⇒ Object
Unit the value is expressed in.
-
#value ⇒ Object
Sum of the underlying metric values over the bucket.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricRollupAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MetricRollupAttributes
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::MetricRollupAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::MetricRollupAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end if attributes.key?(:'bucket') self.bucket = attributes[:'bucket'] else self.bucket = nil end if attributes.key?(:'rollup') self.rollup = attributes[:'rollup'] else self.rollup = nil end end |
Instance Attribute Details
#bucket ⇒ Object
Start of the time bucket this rollup covers.
29 30 31 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 29 def bucket @bucket end |
#name ⇒ Object
Metric series name the rollup is computed from.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 20 def name @name end |
#rollup ⇒ Object
Rollup interval. One of ‘1m`, `5m`, `15m`, `1h`, `6h`, `1d`.
32 33 34 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 32 def rollup @rollup end |
#unit ⇒ Object
Unit the value is expressed in.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 26 def unit @unit end |
#value ⇒ Object
Sum of the underlying metric values over the bucket.
23 24 25 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 23 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 35 def self.attribute_map { :'name' => :'name', :'value' => :'value', :'unit' => :'unit', :'bucket' => :'bucket', :'rollup' => :'rollup' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 67 def self.openapi_nullable Set.new([ :'unit', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 56 def self.openapi_types { :'name' => :'String', :'value' => :'String', :'unit' => :'String', :'bucket' => :'Time', :'rollup' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && value == o.value && unit == o.unit && bucket == o.bucket && rollup == o.rollup end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 224 def hash [name, value, unit, bucket, rollup].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end pattern = Regexp.new(/^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$/) if @value !~ pattern invalid_properties.push("invalid value for \"value\", must conform to the pattern #{pattern}.") end if @bucket.nil? invalid_properties.push('invalid value for "bucket", bucket cannot be nil.') end if @rollup.nil? invalid_properties.push('invalid value for "rollup", rollup cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 157 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_rollup_attributes.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @value.nil? return false if @value !~ Regexp.new(/^(?!^[-+.]*$)[+-]?0*\d*\.?\d*$/) return false if @bucket.nil? return false if @rollup.nil? true end |