Class: SmplkitGeneratedClient::App::MetricsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::MetricsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bulk_ingest_metrics(metric_bulk_request, opts = {}) ⇒ nil
Bulk Ingest Metrics Ingest pre-aggregated metric data points.
-
#bulk_ingest_metrics_with_http_info(metric_bulk_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Bulk Ingest Metrics Ingest pre-aggregated metric data points.
-
#initialize(api_client = ApiClient.default) ⇒ MetricsApi
constructor
A new instance of MetricsApi.
-
#list_metric_names(opts = {}) ⇒ MetricNamesResponse
List Metric Names Return distinct metric names recorded for the account, each with a representative unit.
-
#list_metric_names_with_http_info(opts = {}) ⇒ Array<(MetricNamesResponse, Integer, Hash)>
List Metric Names Return distinct metric names recorded for the account, each with a representative unit.
-
#list_metric_rollups(filter_name, filter_rollup, opts = {}) ⇒ MetricRollupListResponse
List Metric Rollups Query aggregated metric rollups.
-
#list_metric_rollups_with_http_info(filter_name, filter_rollup, opts = {}) ⇒ Array<(MetricRollupListResponse, Integer, Hash)>
List Metric Rollups Query aggregated metric rollups.
-
#list_metrics(filter_name, opts = {}) ⇒ MetricListResponse
List Metrics Query raw metric rows with filtering by name, time range, and dimensions.
-
#list_metrics_with_http_info(filter_name, opts = {}) ⇒ Array<(MetricListResponse, Integer, Hash)>
List Metrics Query raw metric rows with filtering by name, time range, and dimensions.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MetricsApi
Returns a new instance of MetricsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bulk_ingest_metrics(metric_bulk_request, opts = {}) ⇒ nil
Bulk Ingest Metrics Ingest pre-aggregated metric data points. Returns 202 Accepted with no response body.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 27 def bulk_ingest_metrics(metric_bulk_request, opts = {}) bulk_ingest_metrics_with_http_info(metric_bulk_request, opts) nil end |
#bulk_ingest_metrics_with_http_info(metric_bulk_request, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Bulk Ingest Metrics Ingest pre-aggregated metric data points. Returns 202 Accepted with no response body.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 37 def bulk_ingest_metrics_with_http_info(metric_bulk_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetricsApi.bulk_ingest_metrics ...' end # verify the required parameter 'metric_bulk_request' is set if @api_client.config.client_side_validation && metric_bulk_request.nil? fail ArgumentError, "Missing the required parameter 'metric_bulk_request' when calling MetricsApi.bulk_ingest_metrics" end # resource path local_var_path = '/api/v1/metrics/bulk' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(metric_bulk_request) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"MetricsApi.bulk_ingest_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetricsApi#bulk_ingest_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_metric_names(opts = {}) ⇒ MetricNamesResponse
List Metric Names Return distinct metric names recorded for the account, each with a representative unit. Plain-JSON response (not JSON:API) — this is metadata for discovery, not a metric resource. Default sort is ‘name` ascending.
98 99 100 101 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 98 def list_metric_names(opts = {}) data, _status_code, _headers = list_metric_names_with_http_info(opts) data end |
#list_metric_names_with_http_info(opts = {}) ⇒ Array<(MetricNamesResponse, Integer, Hash)>
List Metric Names Return distinct metric names recorded for the account, each with a representative unit. Plain-JSON response (not JSON:API) — this is metadata for discovery, not a metric resource. Default sort is `name` ascending.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 111 def list_metric_names_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetricsApi.list_metric_names ...' end allowable_values = ["name", "-name"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/metric_names' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'meta[total]'] = opts[:'meta_total'] if !opts[:'meta_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetricNamesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"MetricsApi.list_metric_names", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetricsApi#list_metric_names\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_metric_rollups(filter_name, filter_rollup, opts = {}) ⇒ MetricRollupListResponse
List Metric Rollups Query aggregated metric rollups. Requires filter for the aggregation interval.
174 175 176 177 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 174 def list_metric_rollups(filter_name, filter_rollup, opts = {}) data, _status_code, _headers = list_metric_rollups_with_http_info(filter_name, filter_rollup, opts) data end |
#list_metric_rollups_with_http_info(filter_name, filter_rollup, opts = {}) ⇒ Array<(MetricRollupListResponse, Integer, Hash)>
List Metric Rollups Query aggregated metric rollups. Requires filter for the aggregation interval.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 190 def list_metric_rollups_with_http_info(filter_name, filter_rollup, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetricsApi.list_metric_rollups ...' end # verify the required parameter 'filter_name' is set if @api_client.config.client_side_validation && filter_name.nil? fail ArgumentError, "Missing the required parameter 'filter_name' when calling MetricsApi.list_metric_rollups" end # verify the required parameter 'filter_rollup' is set if @api_client.config.client_side_validation && filter_rollup.nil? fail ArgumentError, "Missing the required parameter 'filter_rollup' when calling MetricsApi.list_metric_rollups" end allowable_values = ["bucket", "-bucket"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/metric_rollups' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[name]'] = filter_name query_params[:'filter[rollup]'] = filter_rollup query_params[:'filter[recorded_at]'] = opts[:'filter_recorded_at'] if !opts[:'filter_recorded_at'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'meta[total]'] = opts[:'meta_total'] if !opts[:'meta_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetricRollupListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"MetricsApi.list_metric_rollups", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetricsApi#list_metric_rollups\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_metrics(filter_name, opts = {}) ⇒ MetricListResponse
List Metrics Query raw metric rows with filtering by name, time range, and dimensions.
263 264 265 266 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 263 def list_metrics(filter_name, opts = {}) data, _status_code, _headers = list_metrics_with_http_info(filter_name, opts) data end |
#list_metrics_with_http_info(filter_name, opts = {}) ⇒ Array<(MetricListResponse, Integer, Hash)>
List Metrics Query raw metric rows with filtering by name, time range, and dimensions.
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/metrics_api.rb', line 278 def list_metrics_with_http_info(filter_name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MetricsApi.list_metrics ...' end # verify the required parameter 'filter_name' is set if @api_client.config.client_side_validation && filter_name.nil? fail ArgumentError, "Missing the required parameter 'filter_name' when calling MetricsApi.list_metrics" end allowable_values = ["recorded_at", "-recorded_at", "value", "-value"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/metrics' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[name]'] = filter_name query_params[:'filter[recorded_at]'] = opts[:'filter_recorded_at'] if !opts[:'filter_recorded_at'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'meta[total]'] = opts[:'meta_total'] if !opts[:'meta_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetricListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"MetricsApi.list_metrics", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MetricsApi#list_metrics\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |