Class: SmplkitGeneratedClient::App::SSODomain

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb

Overview

An email domain claimed by an account for SSO routing. A domain is not active until it has been verified by publishing a DNS TXT record containing the ‘dns_txt_token`. Once verified, sign-in attempts on that domain route to this account’s SSO connection. Verified-domain ownership is global across accounts — two accounts cannot both hold the same verified domain.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SSODomain

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SSODomain` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SSODomain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'dns_txt_token')
    self.dns_txt_token = attributes[:'dns_txt_token']
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

When the claim was created.



29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 29

def created_at
  @created_at
end

#dns_txt_tokenObject

Token to publish on the domain’s DNS as a TXT record to prove ownership. The full record value is ‘smplkit-domain-verification=<token>`.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 20

def dns_txt_token
  @dns_txt_token
end

#statusObject

Verification status. ‘pending` means a claim has been registered but DNS TXT verification has not yet succeeded. `verified` means the domain is in use for SSO routing.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 26

def status
  @status
end

#updated_atObject

When the claim was last modified.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 32

def updated_at
  @updated_at
end

#verified_atObject

When the domain was verified. Null until verification succeeds.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 23

def verified_at
  @verified_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 57

def self.attribute_map
  {
    :'dns_txt_token' => :'dns_txt_token',
    :'verified_at' => :'verified_at',
    :'status' => :'status',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 190

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
93
94
95
96
97
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 89

def self.openapi_nullable
  Set.new([
    :'dns_txt_token',
    :'verified_at',
    :'status',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 78

def self.openapi_types
  {
    :'dns_txt_token' => :'String',
    :'verified_at' => :'Time',
    :'status' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
173
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      dns_txt_token == o.dns_txt_token &&
      verified_at == o.verified_at &&
      status == o.status &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 177

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



183
184
185
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 183

def hash
  [dns_txt_token, verified_at, status, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/sso_domain.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "verified"])
  return false unless status_validator.valid?(@status)
  true
end