Class: SmplkitGeneratedClient::App::SubscriptionChangeProjection

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb

Overview

Per-item projected effect of a subscription change.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionChangeProjection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionChangeProjection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionChangeProjection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  else
    self.product = nil
  end

  if attributes.key?(:'from_plan')
    self.from_plan = attributes[:'from_plan']
  else
    self.from_plan = nil
  end

  if attributes.key?(:'to_plan')
    self.to_plan = attributes[:'to_plan']
  else
    self.to_plan = nil
  end

  if attributes.key?(:'monthly_cents')
    self.monthly_cents = attributes[:'monthly_cents']
  else
    self.monthly_cents = nil
  end

  if attributes.key?(:'effect')
    self.effect = attributes[:'effect']
  else
    self.effect = nil
  end

  if attributes.key?(:'prorated_charge_today_cents')
    self.prorated_charge_today_cents = attributes[:'prorated_charge_today_cents']
  else
    self.prorated_charge_today_cents = 0
  end

  if attributes.key?(:'starts_at')
    self.starts_at = attributes[:'starts_at']
  end
end

Instance Attribute Details

#effectObject

‘IMMEDIATE` when the change takes effect at confirmation time (and a prorated charge may apply today). `NEXT_PERIOD` when the change takes effect at the end of the current billing period.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 32

def effect
  @effect
end

#from_planObject

Current plan for this product, or ‘FREE` if it is being added.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 23

def from_plan
  @from_plan
end

#monthly_centsObject

Monthly cost in cents of this enrollment after the change. ‘0` when the enrollment will be dropped.



29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 29

def monthly_cents
  @monthly_cents
end

#productObject

Product key affected by this change.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 20

def product
  @product
end

#prorated_charge_today_centsObject

When ‘effect` is `IMMEDIATE`, the estimated prorated charge for the remainder of the current billing period in cents. Always `0` when `effect` is `NEXT_PERIOD`.



35
36
37
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 35

def prorated_charge_today_cents
  @prorated_charge_today_cents
end

#starts_atObject

When ‘effect` is `NEXT_PERIOD`, the ISO-8601 timestamp at which the change takes effect. `null` when `effect` is `IMMEDIATE` (the change applies on confirmation).



38
39
40
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 38

def starts_at
  @starts_at
end

#to_planObject

Plan the product will be on after the change. ‘FREE` indicates the enrollment will be dropped.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 26

def to_plan
  @to_plan
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 63

def self.attribute_map
  {
    :'product' => :'product',
    :'from_plan' => :'from_plan',
    :'to_plan' => :'to_plan',
    :'monthly_cents' => :'monthly_cents',
    :'effect' => :'effect',
    :'prorated_charge_today_cents' => :'prorated_charge_today_cents',
    :'starts_at' => :'starts_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 99

def self.openapi_nullable
  Set.new([
    :'starts_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 86

def self.openapi_types
  {
    :'product' => :'String',
    :'from_plan' => :'String',
    :'to_plan' => :'String',
    :'monthly_cents' => :'Integer',
    :'effect' => :'String',
    :'prorated_charge_today_cents' => :'Integer',
    :'starts_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      product == o.product &&
      from_plan == o.from_plan &&
      to_plan == o.to_plan &&
      monthly_cents == o.monthly_cents &&
      effect == o.effect &&
      prorated_charge_today_cents == o.prorated_charge_today_cents &&
      starts_at == o.starts_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 276

def hash
  [product, from_plan, to_plan, monthly_cents, effect, prorated_charge_today_cents, starts_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @product.nil?
    invalid_properties.push('invalid value for "product", product cannot be nil.')
  end

  if @from_plan.nil?
    invalid_properties.push('invalid value for "from_plan", from_plan cannot be nil.')
  end

  if @to_plan.nil?
    invalid_properties.push('invalid value for "to_plan", to_plan cannot be nil.')
  end

  if @monthly_cents.nil?
    invalid_properties.push('invalid value for "monthly_cents", monthly_cents cannot be nil.')
  end

  if @effect.nil?
    invalid_properties.push('invalid value for "effect", effect cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_change_projection.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @product.nil?
  return false if @from_plan.nil?
  return false if @to_plan.nil?
  return false if @monthly_cents.nil?
  return false if @effect.nil?
  effect_validator = EnumAttributeValidator.new('String', ["IMMEDIATE", "NEXT_PERIOD"])
  return false unless effect_validator.valid?(@effect)
  true
end