Class: SmplkitGeneratedClient::App::SubscriptionListMeta

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb

Overview

Discount and totals summary attached to a subscription collection response.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionListMeta

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionListMeta` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionListMeta`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'subtotal_cents')
    self.subtotal_cents = attributes[:'subtotal_cents']
  else
    self.subtotal_cents = nil
  end

  if attributes.key?(:'discount_pct')
    self.discount_pct = attributes[:'discount_pct']
  else
    self.discount_pct = nil
  end

  if attributes.key?(:'discount_amount_cents')
    self.discount_amount_cents = attributes[:'discount_amount_cents']
  else
    self.discount_amount_cents = nil
  end

  if attributes.key?(:'discount_source')
    self.discount_source = attributes[:'discount_source']
  else
    self.discount_source = nil
  end

  if attributes.key?(:'total_cents')
    self.total_cents = attributes[:'total_cents']
  else
    self.total_cents = nil
  end

  if attributes.key?(:'next_tier')
    self.next_tier = attributes[:'next_tier']
  end
end

Instance Attribute Details

#discount_amount_centsObject

Discount amount in cents.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 26

def discount_amount_cents
  @discount_amount_cents
end

#discount_pctObject

Effective discount percentage applied.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 23

def discount_pct
  @discount_pct
end

#discount_sourceObject

Source of the discount. ‘VOLUME` indicates the standard volume-discount schedule; `OVERRIDE` indicates a custom discount set on the account.



29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 29

def discount_source
  @discount_source
end

#next_tierObject

Returns the value of attribute next_tier.



34
35
36
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 34

def next_tier
  @next_tier
end

#subtotal_centsObject

Sum of list prices across all subscriptions in cents.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 20

def subtotal_cents
  @subtotal_cents
end

#total_centsObject

Final monthly total in cents after the discount.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 32

def total_cents
  @total_cents
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 59

def self.attribute_map
  {
    :'subtotal_cents' => :'subtotal_cents',
    :'discount_pct' => :'discount_pct',
    :'discount_amount_cents' => :'discount_amount_cents',
    :'discount_source' => :'discount_source',
    :'total_cents' => :'total_cents',
    :'next_tier' => :'next_tier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 81

def self.openapi_types
  {
    :'subtotal_cents' => :'Integer',
    :'discount_pct' => :'Integer',
    :'discount_amount_cents' => :'Integer',
    :'discount_source' => :'String',
    :'total_cents' => :'Integer',
    :'next_tier' => :'NextTierMeta'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      subtotal_cents == o.subtotal_cents &&
      discount_pct == o.discount_pct &&
      discount_amount_cents == o.discount_amount_cents &&
      discount_source == o.discount_source &&
      total_cents == o.total_cents &&
      next_tier == o.next_tier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 262

def hash
  [subtotal_cents, discount_pct, discount_amount_cents, discount_source, total_cents, next_tier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @subtotal_cents.nil?
    invalid_properties.push('invalid value for "subtotal_cents", subtotal_cents cannot be nil.')
  end

  if @discount_pct.nil?
    invalid_properties.push('invalid value for "discount_pct", discount_pct cannot be nil.')
  end

  if @discount_amount_cents.nil?
    invalid_properties.push('invalid value for "discount_amount_cents", discount_amount_cents cannot be nil.')
  end

  if @discount_source.nil?
    invalid_properties.push('invalid value for "discount_source", discount_source cannot be nil.')
  end

  if @total_cents.nil?
    invalid_properties.push('invalid value for "total_cents", total_cents cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_list_meta.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @subtotal_cents.nil?
  return false if @discount_pct.nil?
  return false if @discount_amount_cents.nil?
  return false if @discount_source.nil?
  discount_source_validator = EnumAttributeValidator.new('String', ["VOLUME", "OVERRIDE"])
  return false unless discount_source_validator.valid?(@discount_source)
  return false if @total_cents.nil?
  true
end