Class: SmplkitGeneratedClient::App::SubscriptionRequestAttributes

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb

Overview

Customer’s desired subscription state.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionRequestAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionRequestAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionRequestAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end
end

Instance Attribute Details

#itemsObject

Desired enrollments. Products listed are scheduled to be on the specified plan immediately (for upgrades and new enrollments) or at the end of the current billing period (for downgrades). Products not listed are scheduled to be dropped at the end of the current billing period.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 20

def items
  @items
end

#payment_methodObject

Optional identifier of the payment method to bill against. If omitted, the account’s default payment method is used.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 23

def payment_method
  @payment_method
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 26

def self.attribute_map
  {
    :'items' => :'items',
    :'payment_method' => :'payment_method'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 141

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
56
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 52

def self.openapi_nullable
  Set.new([
    :'payment_method'
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 44

def self.openapi_types
  {
    :'items' => :'Array<SubscriptionItemRequest>',
    :'payment_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



119
120
121
122
123
124
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 119

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      items == o.items &&
      payment_method == o.payment_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


128
129
130
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 128

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



134
135
136
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 134

def hash
  [items, payment_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
93
94
95
96
97
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 89

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 163

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



101
102
103
104
105
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_request_attributes.rb', line 101

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @items.nil?
  true
end