Class: SmplkitGeneratedClient::App::SubscriptionResponseAttributes

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb

Overview

Customer’s subscription as returned by the API.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionResponseAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionResponseAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionResponseAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'current_period_start')
    self.current_period_start = attributes[:'current_period_start']
  end

  if attributes.key?(:'current_period_end')
    self.current_period_end = attributes[:'current_period_end']
  end

  if attributes.key?(:'discount_pct')
    self.discount_pct = attributes[:'discount_pct']
  else
    self.discount_pct = nil
  end

  if attributes.key?(:'discount_source')
    self.discount_source = attributes[:'discount_source']
  else
    self.discount_source = nil
  end

  if attributes.key?(:'subtotal_cents')
    self.subtotal_cents = attributes[:'subtotal_cents']
  else
    self.subtotal_cents = nil
  end

  if attributes.key?(:'discount_amount_cents')
    self.discount_amount_cents = attributes[:'discount_amount_cents']
  else
    self.discount_amount_cents = nil
  end

  if attributes.key?(:'total_cents')
    self.total_cents = attributes[:'total_cents']
  else
    self.total_cents = nil
  end

  if attributes.key?(:'next_tier')
    self.next_tier = attributes[:'next_tier']
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end
end

Instance Attribute Details

#current_period_endObject

ISO-8601 timestamp of the current billing period’s end. Scheduled plan changes take effect at this moment.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 26

def current_period_end
  @current_period_end
end

#current_period_startObject

ISO-8601 timestamp of the current billing period’s start.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 23

def current_period_start
  @current_period_start
end

#discount_amount_centsObject

Amount discounted from the subtotal in cents.



38
39
40
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 38

def discount_amount_cents
  @discount_amount_cents
end

#discount_pctObject

Effective discount percentage applied to the subscription’s monthly invoice. This is the value locked at the time of the customer’s last subscription change; subsequent changes to the public discount schedule do not affect this customer until they themselves change their subscription.



29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 29

def discount_pct
  @discount_pct
end

#discount_sourceObject

‘VOLUME` when the discount comes from the multi-product discount schedule; `OVERRIDE` when an administrator has applied a custom discount.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 32

def discount_source
  @discount_source
end

#itemsObject

One entry per product currently enrolled on the subscription.



49
50
51
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 49

def items
  @items
end

#next_tierObject

Returns the value of attribute next_tier.



43
44
45
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 43

def next_tier
  @next_tier
end

#payment_methodObject

Identifier of the default payment method used to bill this subscription. ‘null` when the subscription has no associated payment method (e.g. fully comped).



46
47
48
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 46

def payment_method
  @payment_method
end

#statusObject

Lifecycle state of the subscription. ‘ACTIVE` while billing is current; `PAST_DUE` after a failed charge; `CANCELED` once the subscription has ended; `null` when the subscription has no billing object (fully comped at 100% discount).



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 20

def status
  @status
end

#subtotal_centsObject

Sum of all item list prices in cents, before discount.



35
36
37
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 35

def subtotal_cents
  @subtotal_cents
end

#total_centsObject

Final monthly total in cents after the discount is applied.



41
42
43
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 41

def total_cents
  @total_cents
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



91
92
93
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 91

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 96

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 74

def self.attribute_map
  {
    :'status' => :'status',
    :'current_period_start' => :'current_period_start',
    :'current_period_end' => :'current_period_end',
    :'discount_pct' => :'discount_pct',
    :'discount_source' => :'discount_source',
    :'subtotal_cents' => :'subtotal_cents',
    :'discount_amount_cents' => :'discount_amount_cents',
    :'total_cents' => :'total_cents',
    :'next_tier' => :'next_tier',
    :'payment_method' => :'payment_method',
    :'items' => :'items'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 342

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
122
123
124
125
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 118

def self.openapi_nullable
  Set.new([
    :'status',
    :'current_period_start',
    :'current_period_end',
    :'payment_method',
  ])
end

.openapi_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 101

def self.openapi_types
  {
    :'status' => :'String',
    :'current_period_start' => :'String',
    :'current_period_end' => :'String',
    :'discount_pct' => :'Integer',
    :'discount_source' => :'String',
    :'subtotal_cents' => :'Integer',
    :'discount_amount_cents' => :'Integer',
    :'total_cents' => :'Integer',
    :'next_tier' => :'NextTierResponse',
    :'payment_method' => :'String',
    :'items' => :'Array<SubscriptionItemResponse>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 311

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      current_period_start == o.current_period_start &&
      current_period_end == o.current_period_end &&
      discount_pct == o.discount_pct &&
      discount_source == o.discount_source &&
      subtotal_cents == o.subtotal_cents &&
      discount_amount_cents == o.discount_amount_cents &&
      total_cents == o.total_cents &&
      next_tier == o.next_tier &&
      payment_method == o.payment_method &&
      items == o.items
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 335

def hash
  [status, current_period_start, current_period_end, discount_pct, discount_source, subtotal_cents, discount_amount_cents, total_cents, next_tier, payment_method, items].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 204

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @discount_pct.nil?
    invalid_properties.push('invalid value for "discount_pct", discount_pct cannot be nil.')
  end

  if @discount_source.nil?
    invalid_properties.push('invalid value for "discount_source", discount_source cannot be nil.')
  end

  if @subtotal_cents.nil?
    invalid_properties.push('invalid value for "subtotal_cents", subtotal_cents cannot be nil.')
  end

  if @discount_amount_cents.nil?
    invalid_properties.push('invalid value for "discount_amount_cents", discount_amount_cents cannot be nil.')
  end

  if @total_cents.nil?
    invalid_properties.push('invalid value for "total_cents", total_cents cannot be nil.')
  end

  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_response_attributes.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @discount_pct.nil?
  return false if @discount_source.nil?
  discount_source_validator = EnumAttributeValidator.new('String', ["VOLUME", "OVERRIDE"])
  return false unless discount_source_validator.valid?(@discount_source)
  return false if @subtotal_cents.nil?
  return false if @discount_amount_cents.nil?
  return false if @total_cents.nil?
  return false if @items.nil?
  true
end