Class: SmplkitGeneratedClient::Audit::ForwarderEnvironment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Audit::ForwarderEnvironment
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb
Overview
Per-environment override for a forwarder’s enablement and configuration.
Instance Attribute Summary collapse
-
#configuration ⇒ Object
Per-environment delivery configuration override.
-
#enabled ⇒ Object
Whether the forwarder delivers events in this environment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForwarderEnvironment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ForwarderEnvironment
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::ForwarderEnvironment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::ForwarderEnvironment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = false end if attributes.key?(:'configuration') self.configuration = attributes[:'configuration'] end end |
Instance Attribute Details
#configuration ⇒ Object
Per-environment delivery configuration override. Omit to inherit the forwarder’s base ‘configuration`. When present, it fully replaces the base configuration for this environment and is validated against the same per-vendor template.
23 24 25 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 23 def configuration @configuration end |
#enabled ⇒ Object
Whether the forwarder delivers events in this environment. A forwarder is enabled in an environment only via this field — the base ‘enabled` is always false.
20 21 22 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 20 def enabled @enabled end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 26 def self.attribute_map { :'enabled' => :'enabled', :'configuration' => :'configuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 124 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 52 def self.openapi_nullable Set.new([ :'configuration' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 44 def self.openapi_types { :'enabled' => :'Boolean', :'configuration' => :'HttpConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
102 103 104 105 106 107 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 102 def ==(o) return true if self.equal?(o) self.class == o.class && enabled == o.enabled && configuration == o.configuration end |
#eql?(o) ⇒ Boolean
111 112 113 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 111 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 117 def hash [enabled, configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
87 88 89 90 91 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 87 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 146 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
95 96 97 98 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_environment.rb', line 95 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |