Class: SmplkitGeneratedClient::Audit::ForwarderTypePlaceholder
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Audit::ForwarderTypePlaceholder
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb
Overview
UI metadata for one “name“ placeholder in the configuration.
Instance Attribute Summary collapse
-
#default ⇒ Object
Pre-selected value when ‘enum` is set, or the default for a free-text field.
-
#enum ⇒ Object
If set, the value must be one of the listed strings — render as a dropdown.
-
#label ⇒ Object
Human-readable label for the input.
-
#placeholder ⇒ Object
HTML-input hint text shown when the field is empty.
-
#secret ⇒ Object
If true, mask the value in the UI and treat as a credential.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForwarderTypePlaceholder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ForwarderTypePlaceholder
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::ForwarderTypePlaceholder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::ForwarderTypePlaceholder`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'secret') self.secret = attributes[:'secret'] else self.secret = false end if attributes.key?(:'enum') if (value = attributes[:'enum']).is_a?(Array) self.enum = value end end if attributes.key?(:'default') self.default = attributes[:'default'] end if attributes.key?(:'placeholder') self.placeholder = attributes[:'placeholder'] end end |
Instance Attribute Details
#default ⇒ Object
Pre-selected value when ‘enum` is set, or the default for a free-text field.
29 30 31 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 29 def default @default end |
#enum ⇒ Object
If set, the value must be one of the listed strings — render as a dropdown.
26 27 28 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 26 def enum @enum end |
#label ⇒ Object
Human-readable label for the input.
20 21 22 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 20 def label @label end |
#placeholder ⇒ Object
HTML-input hint text shown when the field is empty.
32 33 34 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 32 def placeholder @placeholder end |
#secret ⇒ Object
If true, mask the value in the UI and treat as a credential.
23 24 25 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 23 def secret @secret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 35 def self.attribute_map { :'label' => :'label', :'secret' => :'secret', :'enum' => :'enum', :'default' => :'default', :'placeholder' => :'placeholder' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 175 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 72 73 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 67 def self.openapi_nullable Set.new([ :'enum', :'default', :'placeholder' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 56 def self.openapi_types { :'label' => :'String', :'secret' => :'Boolean', :'enum' => :'Array<String>', :'default' => :'String', :'placeholder' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && label == o.label && secret == o.secret && enum == o.enum && default == o.default && placeholder == o.placeholder end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 168 def hash [label, secret, enum, default, placeholder].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 197 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_type_placeholder.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @label.nil? true end |