Class: SmplkitGeneratedClient::Audit::ForwarderTypesApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Audit::ForwarderTypesApi
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_forwarder_type_api_v1_forwarder_types_id_get(id, opts = {}) ⇒ ForwarderTypeResponse
Get Forwarder Type Fetch a single forwarder type from the catalog.
-
#get_forwarder_type_api_v1_forwarder_types_id_get_with_http_info(id, opts = {}) ⇒ Array<(ForwarderTypeResponse, Integer, Hash)>
Get Forwarder Type Fetch a single forwarder type from the catalog.
-
#initialize(api_client = ApiClient.default) ⇒ ForwarderTypesApi
constructor
A new instance of ForwarderTypesApi.
-
#list_forwarder_types_api_v1_forwarder_types_get(opts = {}) ⇒ ForwarderTypeListResponse
List Forwarder Types List all forwarder types in the catalog.
-
#list_forwarder_types_api_v1_forwarder_types_get_with_http_info(opts = {}) ⇒ Array<(ForwarderTypeListResponse, Integer, Hash)>
List Forwarder Types List all forwarder types in the catalog.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ForwarderTypesApi
Returns a new instance of ForwarderTypesApi.
19 20 21 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_forwarder_type_api_v1_forwarder_types_id_get(id, opts = {}) ⇒ ForwarderTypeResponse
Get Forwarder Type Fetch a single forwarder type from the catalog.
27 28 29 30 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 27 def get_forwarder_type_api_v1_forwarder_types_id_get(id, opts = {}) data, _status_code, _headers = get_forwarder_type_api_v1_forwarder_types_id_get_with_http_info(id, opts) data end |
#get_forwarder_type_api_v1_forwarder_types_id_get_with_http_info(id, opts = {}) ⇒ Array<(ForwarderTypeResponse, Integer, Hash)>
Get Forwarder Type Fetch a single forwarder type from the catalog.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 37 def get_forwarder_type_api_v1_forwarder_types_id_get_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ForwarderTypesApi.get_forwarder_type_api_v1_forwarder_types_id_get ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ForwarderTypesApi.get_forwarder_type_api_v1_forwarder_types_id_get" end # resource path local_var_path = '/api/v1/forwarder_types/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ForwarderTypeResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"ForwarderTypesApi.get_forwarder_type_api_v1_forwarder_types_id_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ForwarderTypesApi#get_forwarder_type_api_v1_forwarder_types_id_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_forwarder_types_api_v1_forwarder_types_get(opts = {}) ⇒ ForwarderTypeListResponse
List Forwarder Types List all forwarder types in the catalog. Returns every branded HTTP forwarder type defined in ‘forwarder_types/*.yaml` plus the synthetic `http` (Custom HTTP) entry. The response drives the console’s create-forwarder UX, the docs vendor-reference page, and audit’s own server-side template validation.
89 90 91 92 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 89 def list_forwarder_types_api_v1_forwarder_types_get(opts = {}) data, _status_code, _headers = list_forwarder_types_api_v1_forwarder_types_get_with_http_info(opts) data end |
#list_forwarder_types_api_v1_forwarder_types_get_with_http_info(opts = {}) ⇒ Array<(ForwarderTypeListResponse, Integer, Hash)>
List Forwarder Types List all forwarder types in the catalog. Returns every branded HTTP forwarder type defined in `forwarder_types/*.yaml` plus the synthetic `http` (Custom HTTP) entry. The response drives the console's create-forwarder UX, the docs vendor-reference page, and audit's own server-side template validation.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/forwarder_types_api.rb', line 98 def list_forwarder_types_api_v1_forwarder_types_get_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ForwarderTypesApi.list_forwarder_types_api_v1_forwarder_types_get ...' end # resource path local_var_path = '/api/v1/forwarder_types' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ForwarderTypeListResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"ForwarderTypesApi.list_forwarder_types_api_v1_forwarder_types_get", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ForwarderTypesApi#list_forwarder_types_api_v1_forwarder_types_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |