Class: SmplkitGeneratedClient::Audit::FunctionsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Audit::FunctionsApi
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/functions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#execute_wipe(body, opts = {}) ⇒ WipeResponse
Execute Wipe Delete every audit-database row scoped to the authenticated account.
-
#execute_wipe_with_http_info(body, opts = {}) ⇒ Array<(WipeResponse, Integer, Hash)>
Execute Wipe Delete every audit-database row scoped to the authenticated account.
-
#initialize(api_client = ApiClient.default) ⇒ FunctionsApi
constructor
A new instance of FunctionsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FunctionsApi
Returns a new instance of FunctionsApi.
19 20 21 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/functions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/functions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#execute_wipe(body, opts = {}) ⇒ WipeResponse
Execute Wipe Delete every audit-database row scoped to the authenticated account. Returns the per-table row counts that were deleted along with the completion timestamp. The action is atomic within the audit database — either every account-scoped row is gone, or none is. The body is required to be “{}“; no parameters are accepted.
27 28 29 30 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/functions_api.rb', line 27 def execute_wipe(body, opts = {}) data, _status_code, _headers = execute_wipe_with_http_info(body, opts) data end |
#execute_wipe_with_http_info(body, opts = {}) ⇒ Array<(WipeResponse, Integer, Hash)>
Execute Wipe Delete every audit-database row scoped to the authenticated account. Returns the per-table row counts that were deleted along with the completion timestamp. The action is atomic within the audit database — either every account-scoped row is gone, or none is. The body is required to be ``{}``; no parameters are accepted.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/functions_api.rb', line 37 def execute_wipe_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FunctionsApi.execute_wipe ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling FunctionsApi.execute_wipe" end # resource path local_var_path = '/api/v1/functions/wipe/actions/execute' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'WipeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FunctionsApi.execute_wipe", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FunctionsApi#execute_wipe\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |