Class: SmplkitGeneratedClient::Audit::HttpConfiguration

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb

Overview

HTTP request configuration used to deliver an event to the destination. Used when the parent forwarder’s “forwarder_type“ is one of the HTTP-family destinations (“HTTP“, “DATADOG“, “SPLUNK_HEC“, “SUMO_LOGIC“, “NEW_RELIC“, “HONEYCOMB“, “ELASTIC“). When other transports land (“FTP“, “SQS“, …) their own configuration schemas will join this one as members of a discriminated union under the “configuration“ field of “Forwarder“.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ HttpConfiguration

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::HttpConfiguration` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::HttpConfiguration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = 'POST'
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  end

  if attributes.key?(:'success_status')
    self.success_status = attributes[:'success_status']
  else
    self.success_status = '2xx'
  end
end

Instance Attribute Details

#headersObject

HTTP headers attached to each delivery request.



26
27
28
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 26

def headers
  @headers
end

#methodObject

HTTP method used when delivering an event.



20
21
22
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 20

def method
  @method
end

#success_statusObject

HTTP response status that indicates a successful delivery. Either a specific status code (e.g. ‘200`, `204`) or a status class (`1xx`, `2xx`, `3xx`, `4xx`, `5xx`).



29
30
31
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 29

def success_status
  @success_status
end

#urlObject

Destination URL.



23
24
25
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 23

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 54

def self.attribute_map
  {
    :'method' => :'method',
    :'url' => :'url',
    :'headers' => :'headers',
    :'success_status' => :'success_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 74

def self.openapi_types
  {
    :'method' => :'String',
    :'url' => :'String',
    :'headers' => :'Array<HttpHeader>',
    :'success_status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      method == o.method &&
      url == o.url &&
      headers == o.headers &&
      success_status == o.success_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 228

def hash
  [method, url, headers, success_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 2048
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2048.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.')
  end

  if !@success_status.nil? && @success_status.to_s.length > 3
    invalid_properties.push('invalid value for "success_status", the character length must be smaller than or equal to 3.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
164
165
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/http_configuration.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "PATCH", "DELETE"])
  return false unless method_validator.valid?(@method)
  return false if @url.nil?
  return false if @url.to_s.length > 2048
  return false if @url.to_s.length < 1
  return false if !@success_status.nil? && @success_status.to_s.length > 3
  true
end