Class: SmplkitGeneratedClient::Audit::ResourceTypesApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Audit::ResourceTypesApi
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/resource_types_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ResourceTypesApi
constructor
A new instance of ResourceTypesApi.
-
#list_resource_types(opts = {}) ⇒ ResourceTypeListResponse
List Resource Types List the distinct ‘resource_type` slugs recorded for this account.
-
#list_resource_types_with_http_info(opts = {}) ⇒ Array<(ResourceTypeListResponse, Integer, Hash)>
List Resource Types List the distinct `resource_type` slugs recorded for this account.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ResourceTypesApi
Returns a new instance of ResourceTypesApi.
19 20 21 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/resource_types_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/resource_types_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_resource_types(opts = {}) ⇒ ResourceTypeListResponse
List Resource Types List the distinct ‘resource_type` slugs recorded for this account. The resource `id` is the slug itself. Default sort is `key` ascending; pass `sort=-key` for descending. Useful for populating filter dropdowns in a UI. Results are scoped to the resource types visible under the account’s current plan.
30 31 32 33 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/resource_types_api.rb', line 30 def list_resource_types(opts = {}) data, _status_code, _headers = list_resource_types_with_http_info(opts) data end |
#list_resource_types_with_http_info(opts = {}) ⇒ Array<(ResourceTypeListResponse, Integer, Hash)>
List Resource Types List the distinct `resource_type` slugs recorded for this account. The resource `id` is the slug itself. Default sort is `key` ascending; pass `sort=-key` for descending. Useful for populating filter dropdowns in a UI. Results are scoped to the resource types visible under the account's current plan.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/resource_types_api.rb', line 43 def list_resource_types_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ResourceTypesApi.list_resource_types ...' end allowable_values = ["key", "-key"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/resource_types' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'meta[total]'] = opts[:'meta_total'] if !opts[:'meta_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ResourceTypeListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ResourceTypesApi.list_resource_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ResourceTypesApi#list_resource_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |