Class: SmplkitGeneratedClient::Config::ConfigsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Config::ConfigsApi
- Defined in:
- lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bulk_register_configs(config_bulk_request, opts = {}) ⇒ ConfigBulkResponse
Bulk Register Configs Register configs declared by an SDK.
-
#bulk_register_configs_with_http_info(config_bulk_request, opts = {}) ⇒ Array<(ConfigBulkResponse, Integer, Hash)>
Bulk Register Configs Register configs declared by an SDK.
-
#create_config(config_request, opts = {}) ⇒ ConfigResponse
Create Config Create a config for this account.
-
#create_config_with_http_info(config_request, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Create Config Create a config for this account.
-
#delete_config(id, opts = {}) ⇒ nil
Delete Config Delete a config by its key.
-
#delete_config_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Config Delete a config by its key.
-
#get_config(id, opts = {}) ⇒ ConfigResponse
Get Config Retrieve a single config by its key.
-
#get_config_with_http_info(id, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Get Config Retrieve a single config by its key.
-
#initialize(api_client = ApiClient.default) ⇒ ConfigsApi
constructor
A new instance of ConfigsApi.
-
#list_configs(opts = {}) ⇒ ConfigListResponse
List Configs List configs for this account.
-
#list_configs_with_http_info(opts = {}) ⇒ Array<(ConfigListResponse, Integer, Hash)>
List Configs List configs for this account.
-
#update_config(id, config_request, opts = {}) ⇒ ConfigResponse
Update Config Replace a config entirely.
-
#update_config_with_http_info(id, config_request, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Update Config Replace a config entirely.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConfigsApi
Returns a new instance of ConfigsApi.
19 20 21 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bulk_register_configs(config_bulk_request, opts = {}) ⇒ ConfigBulkResponse
Bulk Register Configs Register configs declared by an SDK. For each item in the batch: - If no config with that key exists, create one with “managed=false“ (auto-discovered) using the declared items, parent, name, and description. - If a config with that key already exists, leave the config row untouched (per ADR-024 2.9). - Either way, upsert a “config_source“ row for “(config, service, environment)“ and refresh its “last_seen“ timestamp. Per ADR-022 2.11 rule 2 this endpoint never enforces “config.managed_configurations“ — discovered configs do not consume a managed slot.
27 28 29 30 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 27 def bulk_register_configs(config_bulk_request, opts = {}) data, _status_code, _headers = bulk_register_configs_with_http_info(config_bulk_request, opts) data end |
#bulk_register_configs_with_http_info(config_bulk_request, opts = {}) ⇒ Array<(ConfigBulkResponse, Integer, Hash)>
Bulk Register Configs Register configs declared by an SDK. For each item in the batch: - If no config with that key exists, create one with ``managed=false`` (auto-discovered) using the declared items, parent, name, and description. - If a config with that key already exists, leave the config row untouched (per ADR-024 2.9). - Either way, upsert a ``config_source`` row for ``(config, service, environment)`` and refresh its ``last_seen`` timestamp. Per ADR-022 2.11 rule 2 this endpoint never enforces ``config.managed_configurations`` — discovered configs do not consume a managed slot.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 37 def bulk_register_configs_with_http_info(config_bulk_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.bulk_register_configs ...' end # verify the required parameter 'config_bulk_request' is set if @api_client.config.client_side_validation && config_bulk_request.nil? fail ArgumentError, "Missing the required parameter 'config_bulk_request' when calling ConfigsApi.bulk_register_configs" end # resource path local_var_path = '/api/v1/configs/bulk' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(config_bulk_request) # return_type return_type = opts[:debug_return_type] || 'ConfigBulkResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.bulk_register_configs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#bulk_register_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_config(config_request, opts = {}) ⇒ ConfigResponse
Create Config Create a config for this account. The caller supplies the config’s key as ‘data.id`. Keys are unique within an account and immutable for the lifetime of the config.
95 96 97 98 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 95 def create_config(config_request, opts = {}) data, _status_code, _headers = create_config_with_http_info(config_request, opts) data end |
#create_config_with_http_info(config_request, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Create Config Create a config for this account. The caller supplies the config's key as `data.id`. Keys are unique within an account and immutable for the lifetime of the config.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 105 def create_config_with_http_info(config_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.create_config ...' end # verify the required parameter 'config_request' is set if @api_client.config.client_side_validation && config_request.nil? fail ArgumentError, "Missing the required parameter 'config_request' when calling ConfigsApi.create_config" end # resource path local_var_path = '/api/v1/configs' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(config_request) # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.create_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#create_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_config(id, opts = {}) ⇒ nil
Delete Config Delete a config by its key. A config that is referenced as ‘parent` by another config cannot be deleted; reparent or remove the parent reference on every child first. The `common` config cannot be deleted.
163 164 165 166 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 163 def delete_config(id, opts = {}) delete_config_with_http_info(id, opts) nil end |
#delete_config_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Config Delete a config by its key. A config that is referenced as `parent` by another config cannot be deleted; reparent or remove the parent reference on every child first. The `common` config cannot be deleted.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 173 def delete_config_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.delete_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.delete_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.delete_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#delete_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_config(id, opts = {}) ⇒ ConfigResponse
Get Config Retrieve a single config by its key.
224 225 226 227 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 224 def get_config(id, opts = {}) data, _status_code, _headers = get_config_with_http_info(id, opts) data end |
#get_config_with_http_info(id, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Get Config Retrieve a single config by its key.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 234 def get_config_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.get_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.get_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.get_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#get_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_configs(opts = {}) ⇒ ConfigListResponse
292 293 294 295 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 292 def list_configs(opts = {}) data, _status_code, _headers = list_configs_with_http_info(opts) data end |
#list_configs_with_http_info(opts = {}) ⇒ Array<(ConfigListResponse, Integer, Hash)>
List Configs List configs for this account. Default sort is `key` ascending. Pass `filter=<parent_key>` to return only the direct children of a specific config, or `filter=<term>` to filter by a case-insensitive substring against `key` or `name`.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 307 def list_configs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.list_configs ...' end allowable_values = ["created_at", "-created_at", "key", "-key", "name", "-name", "updated_at", "-updated_at"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/configs' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[parent]'] = opts[:'filter_parent'] if !opts[:'filter_parent'].nil? query_params[:'filter[search]'] = opts[:'filter_search'] if !opts[:'filter_search'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'meta[total]'] = opts[:'meta_total'] if !opts[:'meta_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConfigListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.list_configs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#list_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_config(id, config_request, opts = {}) ⇒ ConfigResponse
Update Config Replace a config entirely. Every writable field is overwritten.
367 368 369 370 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 367 def update_config(id, config_request, opts = {}) data, _status_code, _headers = update_config_with_http_info(id, config_request, opts) data end |
#update_config_with_http_info(id, config_request, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Update Config Replace a config entirely. Every writable field is overwritten.
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 378 def update_config_with_http_info(id, config_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.update_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.update_config" end # verify the required parameter 'config_request' is set if @api_client.config.client_side_validation && config_request.nil? fail ArgumentError, "Missing the required parameter 'config_request' when calling ConfigsApi.update_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(config_request) # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.update_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#update_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |