Class: SmplkitGeneratedClient::Config::UsageApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Config::UsageApi
- Defined in:
- lib/smplkit/_generated/config/lib/smplkit_config_client/api/usage_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ UsageApi
constructor
A new instance of UsageApi.
-
#list_config_usage(opts = {}) ⇒ UsageListResponse
List Config Usage Return current resource usage counts for the authenticated account.
-
#list_config_usage_with_http_info(opts = {}) ⇒ Array<(UsageListResponse, Integer, Hash)>
List Config Usage Return current resource usage counts for the authenticated account.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/usage_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_config_usage(opts = {}) ⇒ UsageListResponse
List Config Usage Return current resource usage counts for the authenticated account.
27 28 29 30 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/usage_api.rb', line 27 def list_config_usage(opts = {}) data, _status_code, _headers = list_config_usage_with_http_info(opts) data end |
#list_config_usage_with_http_info(opts = {}) ⇒ Array<(UsageListResponse, Integer, Hash)>
List Config Usage Return current resource usage counts for the authenticated account.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/usage_api.rb', line 37 def list_config_usage_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsageApi.list_config_usage ...' end # resource path local_var_path = '/api/v1/usage' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[period]'] = opts[:'filter_period'] if !opts[:'filter_period'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UsageListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsageApi.list_config_usage", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsageApi#list_config_usage\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |