Class: SmplkitGeneratedClient::Flags::FlagBulkItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Flags::FlagBulkItem
- Defined in:
- lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb
Overview
One flag declaration reported by an SDK during bulk registration.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#default ⇒ Object
Returns the value of attribute default.
-
#environment ⇒ Object
Environment reporting the declaration.
-
#id ⇒ Object
Flag key as declared in code.
-
#service ⇒ Object
Service reporting the declaration.
-
#type ⇒ Object
Value type the SDK declared for the flag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagBulkItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlagBulkItem
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Flags::FlagBulkItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Flags::FlagBulkItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'default') self.default = attributes[:'default'] else self.default = nil end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end end |
Instance Attribute Details
#default ⇒ Object
Returns the value of attribute default.
25 26 27 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 25 def default @default end |
#environment ⇒ Object
Environment reporting the declaration. Defaults to ‘unknown`.
31 32 33 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 31 def environment @environment end |
#id ⇒ Object
Flag key as declared in code. URL-safe and stable for the lifetime of the flag.
20 21 22 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 20 def id @id end |
#service ⇒ Object
Service reporting the declaration. Defaults to ‘unknown`.
28 29 30 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 28 def service @service end |
#type ⇒ Object
Value type the SDK declared for the flag. Accepted case-insensitively.
23 24 25 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 23 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 56 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'default' => :'default', :'service' => :'service', :'environment' => :'environment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 213 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 93 94 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 88 def self.openapi_nullable Set.new([ :'default', :'service', :'environment' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 77 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'default' => :'Object', :'service' => :'String', :'environment' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && default == o.default && service == o.service && environment == o.environment end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 206 def hash [id, type, default, service, environment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 235 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag_bulk_item.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["BOOLEAN", "STRING", "NUMERIC", "JSON"]) return false unless type_validator.valid?(@type) true end |