Class: SmplkitGeneratedClient::Flags::FlagsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Flags::FlagsApi
- Defined in:
- lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#bulk_register_flags(flag_bulk_request, opts = {}) ⇒ FlagBulkResponse
Bulk Register Flags Register flags discovered by an SDK.
-
#bulk_register_flags_with_http_info(flag_bulk_request, opts = {}) ⇒ Array<(FlagBulkResponse, Integer, Hash)>
Bulk Register Flags Register flags discovered by an SDK.
-
#create_flag(flag_response, opts = {}) ⇒ FlagResponse
Create Flag Create a new feature flag.
-
#create_flag_with_http_info(flag_response, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Create Flag Create a new feature flag.
-
#delete_flag(id, opts = {}) ⇒ nil
Delete Flag Delete a feature flag by its key.
-
#delete_flag_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Flag Delete a feature flag by its key.
-
#get_flag(id, opts = {}) ⇒ FlagResponse
Get Flag Return a feature flag by its key.
-
#get_flag_with_http_info(id, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Get Flag Return a feature flag by its key.
-
#initialize(api_client = ApiClient.default) ⇒ FlagsApi
constructor
A new instance of FlagsApi.
-
#list_flags(opts = {}) ⇒ FlagListResponse
List Flags List all feature flags for the authenticated account.
-
#list_flags_with_http_info(opts = {}) ⇒ Array<(FlagListResponse, Integer, Hash)>
List Flags List all feature flags for the authenticated account.
-
#update_flag(id, flag_response, opts = {}) ⇒ FlagResponse
Update Flag Replace a feature flag entirely.
-
#update_flag_with_http_info(id, flag_response, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Update Flag Replace a feature flag entirely.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#bulk_register_flags(flag_bulk_request, opts = {}) ⇒ FlagBulkResponse
Bulk Register Flags Register flags discovered by an SDK. Creates new flags or updates source observations on existing ones.
27 28 29 30 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 27 def bulk_register_flags(flag_bulk_request, opts = {}) data, _status_code, _headers = bulk_register_flags_with_http_info(flag_bulk_request, opts) data end |
#bulk_register_flags_with_http_info(flag_bulk_request, opts = {}) ⇒ Array<(FlagBulkResponse, Integer, Hash)>
Bulk Register Flags Register flags discovered by an SDK. Creates new flags or updates source observations on existing ones.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 37 def bulk_register_flags_with_http_info(flag_bulk_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.bulk_register_flags ...' end # verify the required parameter 'flag_bulk_request' is set if @api_client.config.client_side_validation && flag_bulk_request.nil? fail ArgumentError, "Missing the required parameter 'flag_bulk_request' when calling FlagsApi.bulk_register_flags" end # resource path local_var_path = '/api/v1/flags/bulk' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(flag_bulk_request) # return_type return_type = opts[:debug_return_type] || 'FlagBulkResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.bulk_register_flags", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#bulk_register_flags\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_flag(flag_response, opts = {}) ⇒ FlagResponse
Create Flag Create a new feature flag. The caller provides the id (key) in the request body.
95 96 97 98 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 95 def create_flag(flag_response, opts = {}) data, _status_code, _headers = create_flag_with_http_info(flag_response, opts) data end |
#create_flag_with_http_info(flag_response, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Create Flag Create a new feature flag. The caller provides the id (key) in the request body.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 105 def create_flag_with_http_info(flag_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.create_flag ...' end # verify the required parameter 'flag_response' is set if @api_client.config.client_side_validation && flag_response.nil? fail ArgumentError, "Missing the required parameter 'flag_response' when calling FlagsApi.create_flag" end # resource path local_var_path = '/api/v1/flags' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(flag_response) # return_type return_type = opts[:debug_return_type] || 'FlagResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.create_flag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#create_flag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_flag(id, opts = {}) ⇒ nil
Delete Flag Delete a feature flag by its key.
163 164 165 166 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 163 def delete_flag(id, opts = {}) delete_flag_with_http_info(id, opts) nil end |
#delete_flag_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Flag Delete a feature flag by its key.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 173 def delete_flag_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.delete_flag ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FlagsApi.delete_flag" end # resource path local_var_path = '/api/v1/flags/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.delete_flag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#delete_flag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_flag(id, opts = {}) ⇒ FlagResponse
Get Flag Return a feature flag by its key.
224 225 226 227 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 224 def get_flag(id, opts = {}) data, _status_code, _headers = get_flag_with_http_info(id, opts) data end |
#get_flag_with_http_info(id, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Get Flag Return a feature flag by its key.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 234 def get_flag_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.get_flag ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FlagsApi.get_flag" end # resource path local_var_path = '/api/v1/flags/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.get_flag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#get_flag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_flags(opts = {}) ⇒ FlagListResponse
List Flags List all feature flags for the authenticated account.
290 291 292 293 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 290 def list_flags(opts = {}) data, _status_code, _headers = list_flags_with_http_info(opts) data end |
#list_flags_with_http_info(opts = {}) ⇒ Array<(FlagListResponse, Integer, Hash)>
List Flags List all feature flags for the authenticated account.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 303 def list_flags_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.list_flags ...' end # resource path local_var_path = '/api/v1/flags' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[type]'] = opts[:'filter_type'] if !opts[:'filter_type'].nil? query_params[:'filter[managed]'] = opts[:'filter_managed'] if !opts[:'filter_managed'].nil? query_params[:'filter[references_context]'] = opts[:'filter_references_context'] if !opts[:'filter_references_context'].nil? query_params[:'filter[references_context_type]'] = opts[:'filter_references_context_type'] if !opts[:'filter_references_context_type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.list_flags", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#list_flags\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_flag(id, flag_response, opts = {}) ⇒ FlagResponse
Update Flag Replace a feature flag entirely.
357 358 359 360 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 357 def update_flag(id, flag_response, opts = {}) data, _status_code, _headers = update_flag_with_http_info(id, flag_response, opts) data end |
#update_flag_with_http_info(id, flag_response, opts = {}) ⇒ Array<(FlagResponse, Integer, Hash)>
Update Flag Replace a feature flag entirely.
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/flags_api.rb', line 368 def update_flag_with_http_info(id, flag_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FlagsApi.update_flag ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling FlagsApi.update_flag" end # verify the required parameter 'flag_response' is set if @api_client.config.client_side_validation && flag_response.nil? fail ArgumentError, "Missing the required parameter 'flag_response' when calling FlagsApi.update_flag" end # resource path local_var_path = '/api/v1/flags/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(flag_response) # return_type return_type = opts[:debug_return_type] || 'FlagResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FlagsApi.update_flag", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FlagsApi#update_flag\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |