Class: SmplkitGeneratedClient::Jobs::JobEnvironment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb

Overview

Per-environment override for a job’s enablement, schedule, and configuration.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ JobEnvironment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Jobs::JobEnvironment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Jobs::JobEnvironment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = false
  end

  if attributes.key?(:'schedule')
    self.schedule = attributes[:'schedule']
  end

  if attributes.key?(:'timezone')
    self.timezone = attributes[:'timezone']
  end

  if attributes.key?(:'configuration')
    self.configuration = attributes[:'configuration']
  end

  if attributes.key?(:'retry_policy')
    self.retry_policy = attributes[:'retry_policy']
  end

  if attributes.key?(:'next_run_at')
    self.next_run_at = attributes[:'next_run_at']
  end
end

Instance Attribute Details

#configurationObject

Per-environment HTTP request override. Omit to inherit the job’s base ‘configuration`. When present, it fully replaces the base configuration for runs in this environment.



29
30
31
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 29

def configuration
  @configuration
end

#enabledObject

Whether the job schedules runs in this environment. A job runs in an environment only via this field; it is disabled in every environment by default.



20
21
22
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 20

def enabled
  @enabled
end

#next_run_atObject

The next scheduled fire time in this environment. ‘null` when the environment is not enabled, or once a one-off run has fired.



35
36
37
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 35

def next_run_at
  @next_run_at
end

#retry_policyObject

Per-environment retry-policy override — the ‘id` of a retry policy (or `Default`). Omit to inherit the job’s base ‘retry_policy`. When present, runs in this environment retry according to this policy instead of the base.



32
33
34
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 32

def retry_policy
  @retry_policy
end

#scheduleObject

Per-environment schedule override. Omit to inherit the job’s base ‘schedule`. When present, it must be a 5-field cron expression (e.g. `0 3 * * *`), evaluated in this environment’s effective ‘timezone` (the per-environment override, else the base, else UTC), and is only allowed on a recurring (cron) job — it varies the cadence within that environment. It cannot appear on a manual or one-off job, and cannot change a job’s kind.



23
24
25
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 23

def schedule
  @schedule
end

#timezoneObject

Per-environment timezone override for evaluating this environment’s cron ‘schedule`. Omit to inherit the base `timezone` (else UTC). When present, it must be a valid IANA timezone key (e.g. `America/New_York`). Only valid on a recurring (cron) job; it may be set on an environment that inherits the base schedule (it need not also override `schedule`).



26
27
28
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 26

def timezone
  @timezone
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 38

def self.attribute_map
  {
    :'enabled' => :'enabled',
    :'schedule' => :'schedule',
    :'timezone' => :'timezone',
    :'configuration' => :'configuration',
    :'retry_policy' => :'retry_policy',
    :'next_run_at' => :'next_run_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
80
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 72

def self.openapi_nullable
  Set.new([
    :'schedule',
    :'timezone',
    :'configuration',
    :'retry_policy',
    :'next_run_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 60

def self.openapi_types
  {
    :'enabled' => :'Boolean',
    :'schedule' => :'String',
    :'timezone' => :'String',
    :'configuration' => :'JobHttpConfiguration',
    :'retry_policy' => :'String',
    :'next_run_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      enabled == o.enabled &&
      schedule == o.schedule &&
      timezone == o.timezone &&
      configuration == o.configuration &&
      retry_policy == o.retry_policy &&
      next_run_at == o.next_run_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 161

def hash
  [enabled, schedule, timezone, configuration, retry_policy, next_run_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/job_environment.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end