Class: SmplkitGeneratedClient::Jobs::RunStatFailure

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb

Overview

One recently failed run.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RunStatFailure

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Jobs::RunStatFailure` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Jobs::RunStatFailure`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'job')
    self.job = attributes[:'job']
  else
    self.job = nil
  end

  if attributes.key?(:'job_name')
    self.job_name = attributes[:'job_name']
  end

  if attributes.key?(:'failure_reason')
    self.failure_reason = attributes[:'failure_reason']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#created_atObject

When the failed run was created.



29
30
31
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 29

def created_at
  @created_at
end

#failure_reasonObject

Why the run failed; null when unrecorded.



26
27
28
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 26

def failure_reason
  @failure_reason
end

#jobObject

Key of the job the failed run belongs to.



20
21
22
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 20

def job
  @job
end

#job_nameObject

Display name of that job, resolved at read time; null when the job no longer exists.



23
24
25
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 23

def job_name
  @job_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 54

def self.attribute_map
  {
    :'job' => :'job',
    :'job_name' => :'job_name',
    :'failure_reason' => :'failure_reason',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
88
89
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 84

def self.openapi_nullable
  Set.new([
    :'job_name',
    :'failure_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 74

def self.openapi_types
  {
    :'job' => :'String',
    :'job_name' => :'String',
    :'failure_reason' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      job == o.job &&
      job_name == o.job_name &&
      failure_reason == o.failure_reason &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 204

def hash
  [job, job_name, failure_reason, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @job.nil?
    invalid_properties.push('invalid value for "job", job cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
# File 'lib/smplkit/_generated/jobs/lib/smplkit_jobs_client/models/run_stat_failure.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @job.nil?
  failure_reason_validator = EnumAttributeValidator.new('String', ["TIMEOUT", "CONNECTION_ERROR", "NON_SUCCESS_STATUS", "SSRF_BLOCKED", "QUOTA_EXCEEDED", "WORKER_LOST"])
  return false unless failure_reason_validator.valid?(@failure_reason)
  return false if @created_at.nil?
  true
end