Class: SmplkitGeneratedClient::Logging::LoggerSource

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb

Overview

A single service / environment observation of a logger. A source row exists for every (service, environment) pair that has reported the logger via the bulk registration endpoint. The row’s levels reflect what the SDK saw on the most recent report.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoggerSource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Logging::LoggerSource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Logging::LoggerSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'resolved_level')
    self.resolved_level = attributes[:'resolved_level']
  end

  if attributes.key?(:'first_observed')
    self.first_observed = attributes[:'first_observed']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

When the source row was created.



38
39
40
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 38

def created_at
  @created_at
end

#environmentObject

Environment the service was running in when it reported the logger.



23
24
25
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 23

def environment
  @environment
end

#first_observedObject

When this service / environment combination first reported the logger.



32
33
34
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 32

def first_observed
  @first_observed
end

#last_seenObject

Most recent report received for this service / environment combination.



35
36
37
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 35

def last_seen
  @last_seen
end

#levelObject

Level explicitly set on the logger in the source runtime. ‘null` when the runtime inherits its level.



26
27
28
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 26

def level
  @level
end

#resolved_levelObject

Effective level the runtime resolved for the logger.



29
30
31
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 29

def resolved_level
  @resolved_level
end

#serviceObject

Service that reported the logger.



20
21
22
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 20

def service
  @service
end

#updated_atObject

When the source row was last refreshed.



41
42
43
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 41

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 44

def self.attribute_map
  {
    :'service' => :'service',
    :'environment' => :'environment',
    :'level' => :'level',
    :'resolved_level' => :'resolved_level',
    :'first_observed' => :'first_observed',
    :'last_seen' => :'last_seen',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 82

def self.openapi_nullable
  Set.new([
    :'level',
    :'first_observed',
    :'last_seen',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 68

def self.openapi_types
  {
    :'service' => :'String',
    :'environment' => :'String',
    :'level' => :'String',
    :'resolved_level' => :'String',
    :'first_observed' => :'Time',
    :'last_seen' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      service == o.service &&
      environment == o.environment &&
      level == o.level &&
      resolved_level == o.resolved_level &&
      first_observed == o.first_observed &&
      last_seen == o.last_seen &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 179

def hash
  [service, environment, level, resolved_level, first_observed, last_seen, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end