Class: SmplkitGeneratedClient::Logging::ServicesApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Logging::ServicesApi
- Defined in:
- lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/services_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ServicesApi
constructor
A new instance of ServicesApi.
-
#list_services(opts = {}) ⇒ ServiceListResponse
List Services Return the distinct service names observed across all logger sources for the account.
-
#list_services_with_http_info(opts = {}) ⇒ Array<(ServiceListResponse, Integer, Hash)>
List Services Return the distinct service names observed across all logger sources for the account.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ServicesApi
Returns a new instance of ServicesApi.
19 20 21 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/services_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/services_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_services(opts = {}) ⇒ ServiceListResponse
List Services Return the distinct service names observed across all logger sources for the account.
26 27 28 29 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/services_api.rb', line 26 def list_services(opts = {}) data, _status_code, _headers = list_services_with_http_info(opts) data end |
#list_services_with_http_info(opts = {}) ⇒ Array<(ServiceListResponse, Integer, Hash)>
List Services Return the distinct service names observed across all logger sources for the account.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/services_api.rb', line 35 def list_services_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServicesApi.list_services ...' end # resource path local_var_path = '/api/v1/services' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ServiceListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ServicesApi.list_services", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServicesApi#list_services\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |