Class: Smplkit::Flags::FlagStats

Inherits:
Struct
  • Object
show all
Defined in:
lib/smplkit/flags/client.rb

Overview

Evaluation statistics for the flags runtime.

Instance Attribute Summary collapse

Instance Attribute Details

#cache_hitsInteger (readonly)

Returns number of flag evaluations served from the local cache.

Returns:

  • (Integer)

    number of flag evaluations served from the local cache.



115
# File 'lib/smplkit/flags/client.rb', line 115

FlagStats = Struct.new(:cache_hits, :cache_misses, keyword_init: true)

#cache_missesInteger (readonly)

Returns number of flag evaluations that missed the cache and were evaluated from the flag definitions.

Returns:

  • (Integer)

    number of flag evaluations that missed the cache and were evaluated from the flag definitions.



115
# File 'lib/smplkit/flags/client.rb', line 115

FlagStats = Struct.new(:cache_hits, :cache_misses, keyword_init: true)