Class: SmplkitGeneratedClient::App::Account

Inherits:
ApiModelBase show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Account

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::Account` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::Account`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'has_stripe_customer')
    self.has_stripe_customer = attributes[:'has_stripe_customer']
  else
    self.has_stripe_customer = false
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'deleted_at')
    self.deleted_at = attributes[:'deleted_at']
  end

  if attributes.key?(:'product_subscriptions')
    if (value = attributes[:'product_subscriptions']).is_a?(Hash)
      self.product_subscriptions = value
    end
  end

  if attributes.key?(:'entry_point')
    self.entry_point = attributes[:'entry_point']
  end

  if attributes.key?(:'show_sample_data')
    self.show_sample_data = attributes[:'show_sample_data']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 26

def created_at
  @created_at
end

#deleted_atObject

Returns the value of attribute deleted_at.



28
29
30
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 28

def deleted_at
  @deleted_at
end

#entry_pointObject

Registration entry point (from account.data)



33
34
35
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 33

def entry_point
  @entry_point
end

#expires_atObject

Returns the value of attribute expires_at.



24
25
26
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 24

def expires_at
  @expires_at
end

#has_stripe_customerObject

Returns the value of attribute has_stripe_customer.



22
23
24
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 22

def has_stripe_customer
  @has_stripe_customer
end

#keyObject

Returns the value of attribute key.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 20

def key
  @key
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 18

def name
  @name
end

#product_subscriptionsObject

Returns the value of attribute product_subscriptions.



30
31
32
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 30

def product_subscriptions
  @product_subscriptions
end

#show_sample_dataObject

Whether sample data is active (from account.settings)



36
37
38
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 36

def show_sample_data
  @show_sample_data
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 39

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'has_stripe_customer' => :'has_stripe_customer',
    :'expires_at' => :'expires_at',
    :'created_at' => :'created_at',
    :'deleted_at' => :'deleted_at',
    :'product_subscriptions' => :'product_subscriptions',
    :'entry_point' => :'entry_point',
    :'show_sample_data' => :'show_sample_data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
83
84
85
86
87
88
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 79

def self.openapi_nullable
  Set.new([
    :'expires_at',
    :'created_at',
    :'deleted_at',
    :'product_subscriptions',
    :'entry_point',
    :'show_sample_data'
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 64

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'has_stripe_customer' => :'Boolean',
    :'expires_at' => :'Time',
    :'created_at' => :'Time',
    :'deleted_at' => :'Time',
    :'product_subscriptions' => :'Hash<String, Object>',
    :'entry_point' => :'String',
    :'show_sample_data' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 216

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      has_stripe_customer == o.has_stripe_customer &&
      expires_at == o.expires_at &&
      created_at == o.created_at &&
      deleted_at == o.deleted_at &&
      product_subscriptions == o.product_subscriptions &&
      entry_point == o.entry_point &&
      show_sample_data == o.show_sample_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 238

def hash
  [name, key, has_stripe_customer, expires_at, created_at, deleted_at, product_subscriptions, entry_point, show_sample_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @key.to_s.length > 255
    invalid_properties.push('invalid value for "key", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/account.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @key.nil?
  return false if @key.to_s.length > 255
  true
end