Class: SmplkitGeneratedClient::App::ApiKey

Inherits:
ApiModelBase show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApiKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::ApiKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::ApiKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Hash)
      self.scopes = value
    end
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'last_used_at')
    self.last_used_at = attributes[:'last_used_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Hash)
      self.data = value
    end
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 32

def created_at
  @created_at
end

#created_byObject

Returns the value of attribute created_by.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 26

def created_by
  @created_by
end

#dataObject

Returns the value of attribute data.



36
37
38
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 36

def data
  @data
end

#expires_atObject

Returns the value of attribute expires_at.



28
29
30
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 28

def expires_at
  @expires_at
end

#keyObject

Returns the value of attribute key.



22
23
24
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 22

def key
  @key
end

#last_used_atObject

Returns the value of attribute last_used_at.



30
31
32
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 30

def last_used_at
  @last_used_at
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 18

def name
  @name
end

#scopesObject

Returns the value of attribute scopes.



24
25
26
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 24

def scopes
  @scopes
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 20

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



34
35
36
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 39

def self.attribute_map
  {
    :'name' => :'name',
    :'status' => :'status',
    :'key' => :'key',
    :'scopes' => :'scopes',
    :'created_by' => :'created_by',
    :'expires_at' => :'expires_at',
    :'last_used_at' => :'last_used_at',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'data' => :'data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 81

def self.openapi_nullable
  Set.new([
    :'status',
    :'key',
    :'created_by',
    :'expires_at',
    :'last_used_at',
    :'created_at',
    :'updated_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 65

def self.openapi_types
  {
    :'name' => :'String',
    :'status' => :'String',
    :'key' => :'String',
    :'scopes' => :'Hash<String, Object>',
    :'created_by' => :'String',
    :'expires_at' => :'Time',
    :'last_used_at' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'data' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 197

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      status == o.status &&
      key == o.key &&
      scopes == o.scopes &&
      created_by == o.created_by &&
      expires_at == o.expires_at &&
      last_used_at == o.last_used_at &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      data == o.data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 220

def hash
  [name, status, key, scopes, created_by, expires_at, last_used_at, created_at, updated_at, data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/api_key.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 255
  true
end