Class: SmplkitGeneratedClient::App::Invitation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::Invitation
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb
Instance Attribute Summary collapse
-
#account_name ⇒ Object
Returns the value of attribute account_name.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#email ⇒ Object
Returns the value of attribute email.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#invited_by ⇒ Object
Returns the value of attribute invited_by.
-
#inviter_display_name ⇒ Object
Returns the value of attribute inviter_display_name.
-
#role ⇒ Object
Returns the value of attribute role.
-
#status ⇒ Object
Returns the value of attribute status.
-
#token ⇒ Object
Returns the value of attribute token.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Invitation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Invitation
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::Invitation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::Invitation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'invited_by') self.invited_by = attributes[:'invited_by'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'inviter_display_name') self.inviter_display_name = attributes[:'inviter_display_name'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#account_name ⇒ Object
Returns the value of attribute account_name.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 26 def account_name @account_name end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 34 def created_at @created_at end |
#email ⇒ Object
Returns the value of attribute email.
18 19 20 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 18 def email @email end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
32 33 34 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 32 def expires_at @expires_at end |
#invited_by ⇒ Object
Returns the value of attribute invited_by.
24 25 26 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 24 def invited_by @invited_by end |
#inviter_display_name ⇒ Object
Returns the value of attribute inviter_display_name.
28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 28 def inviter_display_name @inviter_display_name end |
#role ⇒ Object
Returns the value of attribute role.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 20 def role @role end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 22 def status @status end |
#token ⇒ Object
Returns the value of attribute token.
30 31 32 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 30 def token @token end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
36 37 38 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 36 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 39 def self.attribute_map { :'email' => :'email', :'role' => :'role', :'status' => :'status', :'invited_by' => :'invited_by', :'account_name' => :'account_name', :'inviter_display_name' => :'inviter_display_name', :'token' => :'token', :'expires_at' => :'expires_at', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 81 def self.openapi_nullable Set.new([ :'email', :'role', :'status', :'invited_by', :'account_name', :'inviter_display_name', :'token', :'expires_at', :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 65 def self.openapi_types { :'email' => :'String', :'role' => :'String', :'status' => :'String', :'invited_by' => :'String', :'account_name' => :'String', :'inviter_display_name' => :'String', :'token' => :'String', :'expires_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && email == o.email && role == o.role && status == o.status && invited_by == o.invited_by && account_name == o.account_name && inviter_display_name == o.inviter_display_name && token == o.token && expires_at == o.expires_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 193 def hash [email, role, status, invited_by, account_name, inviter_display_name, token, expires_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invitation.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |