Class: SmplkitGeneratedClient::App::InvitationsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::InvitationsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#accept_invitation(invitation_accept_request, opts = {}) ⇒ InvitationResponse
Accept Invitation Accept an invitation using a token from the invitation email.
-
#accept_invitation_with_http_info(invitation_accept_request, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Accept Invitation Accept an invitation using a token from the invitation email.
-
#create_invitations(invitation_bulk_create_request, opts = {}) ⇒ InvitationListResponse
Bulk Create Invitations Send one or more invitations to join the account.
-
#create_invitations_with_http_info(invitation_bulk_create_request, opts = {}) ⇒ Array<(InvitationListResponse, Integer, Hash)>
Bulk Create Invitations Send one or more invitations to join the account.
-
#initialize(api_client = ApiClient.default) ⇒ InvitationsApi
constructor
A new instance of InvitationsApi.
-
#list_invitations(opts = {}) ⇒ InvitationListResponse
List Invitations List invitations.
-
#list_invitations_with_http_info(opts = {}) ⇒ Array<(InvitationListResponse, Integer, Hash)>
List Invitations List invitations.
-
#resend_invitation(id, opts = {}) ⇒ InvitationResponse
Resend Invitation Resend a pending invitation email by id.
-
#resend_invitation_with_http_info(id, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Resend Invitation Resend a pending invitation email by id.
-
#revoke_invitation(id, opts = {}) ⇒ InvitationResponse
Revoke Invitation Revoke a pending invitation by id.
-
#revoke_invitation_with_http_info(id, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Revoke Invitation Revoke a pending invitation by id.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InvitationsApi
Returns a new instance of InvitationsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#accept_invitation(invitation_accept_request, opts = {}) ⇒ InvitationResponse
Accept Invitation Accept an invitation using a token from the invitation email.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 27 def accept_invitation(invitation_accept_request, opts = {}) data, _status_code, _headers = accept_invitation_with_http_info(invitation_accept_request, opts) data end |
#accept_invitation_with_http_info(invitation_accept_request, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Accept Invitation Accept an invitation using a token from the invitation email.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 37 def accept_invitation_with_http_info(invitation_accept_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.accept_invitation ...' end # verify the required parameter 'invitation_accept_request' is set if @api_client.config.client_side_validation && invitation_accept_request.nil? fail ArgumentError, "Missing the required parameter 'invitation_accept_request' when calling InvitationsApi.accept_invitation" end # resource path local_var_path = '/api/v1/invitations/accept' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(invitation_accept_request) # return_type return_type = opts[:debug_return_type] || 'InvitationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"InvitationsApi.accept_invitation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#accept_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_invitations(invitation_bulk_create_request, opts = {}) ⇒ InvitationListResponse
Bulk Create Invitations Send one or more invitations to join the account.
95 96 97 98 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 95 def create_invitations(invitation_bulk_create_request, opts = {}) data, _status_code, _headers = create_invitations_with_http_info(invitation_bulk_create_request, opts) data end |
#create_invitations_with_http_info(invitation_bulk_create_request, opts = {}) ⇒ Array<(InvitationListResponse, Integer, Hash)>
Bulk Create Invitations Send one or more invitations to join the account.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 105 def create_invitations_with_http_info(invitation_bulk_create_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.create_invitations ...' end # verify the required parameter 'invitation_bulk_create_request' is set if @api_client.config.client_side_validation && invitation_bulk_create_request.nil? fail ArgumentError, "Missing the required parameter 'invitation_bulk_create_request' when calling InvitationsApi.create_invitations" end # resource path local_var_path = '/api/v1/invitations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(invitation_bulk_create_request) # return_type return_type = opts[:debug_return_type] || 'InvitationListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"InvitationsApi.create_invitations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#create_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_invitations(opts = {}) ⇒ InvitationListResponse
List Invitations List invitations. Authenticated admins list invitations for their own account and may narrow by status. Unauthenticated callers must pass “filter“ to look up a specific invitation by its token — used to render the invitation preview before sign-in. The token-filter path always returns an array of 0 or 1 elements.
164 165 166 167 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 164 def list_invitations(opts = {}) data, _status_code, _headers = list_invitations_with_http_info(opts) data end |
#list_invitations_with_http_info(opts = {}) ⇒ Array<(InvitationListResponse, Integer, Hash)>
List Invitations List invitations. Authenticated admins list invitations for their own account and may narrow by status. Unauthenticated callers must pass ``filter`` to look up a specific invitation by its token — used to render the invitation preview before sign-in. The token-filter path always returns an array of 0 or 1 elements.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 175 def list_invitations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.list_invitations ...' end # resource path local_var_path = '/api/v1/invitations' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[status]'] = opts[:'filter_status'] if !opts[:'filter_status'].nil? query_params[:'filter[token]'] = opts[:'filter_token'] if !opts[:'filter_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InvitationListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"InvitationsApi.list_invitations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#list_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#resend_invitation(id, opts = {}) ⇒ InvitationResponse
Resend Invitation Resend a pending invitation email by id.
226 227 228 229 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 226 def resend_invitation(id, opts = {}) data, _status_code, _headers = resend_invitation_with_http_info(id, opts) data end |
#resend_invitation_with_http_info(id, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Resend Invitation Resend a pending invitation email by id.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 236 def resend_invitation_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.resend_invitation ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling InvitationsApi.resend_invitation" end # resource path local_var_path = '/api/v1/invitations/{id}/actions/resend'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InvitationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"InvitationsApi.resend_invitation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#resend_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_invitation(id, opts = {}) ⇒ InvitationResponse
Revoke Invitation Revoke a pending invitation by id.
289 290 291 292 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 289 def revoke_invitation(id, opts = {}) data, _status_code, _headers = revoke_invitation_with_http_info(id, opts) data end |
#revoke_invitation_with_http_info(id, opts = {}) ⇒ Array<(InvitationResponse, Integer, Hash)>
Revoke Invitation Revoke a pending invitation by id.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/invitations_api.rb', line 299 def revoke_invitation_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InvitationsApi.revoke_invitation ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling InvitationsApi.revoke_invitation" end # resource path local_var_path = '/api/v1/invitations/{id}/actions/revoke'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'InvitationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"InvitationsApi.revoke_invitation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InvitationsApi#revoke_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |