Class: SmplkitGeneratedClient::App::Invoice
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::Invoice
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb
Instance Attribute Summary collapse
-
#amount_due ⇒ Object
Returns the value of attribute amount_due.
-
#amount_paid ⇒ Object
Returns the value of attribute amount_paid.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#description ⇒ Object
Returns the value of attribute description.
-
#hosted_invoice_url ⇒ Object
Returns the value of attribute hosted_invoice_url.
-
#invoice_pdf ⇒ Object
Returns the value of attribute invoice_pdf.
-
#number ⇒ Object
Returns the value of attribute number.
-
#paid_at ⇒ Object
Returns the value of attribute paid_at.
-
#period_end ⇒ Object
Returns the value of attribute period_end.
-
#period_start ⇒ Object
Returns the value of attribute period_start.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Invoice
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Invoice
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::Invoice` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::Invoice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] else self.number = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'amount_due') self.amount_due = attributes[:'amount_due'] else self.amount_due = nil end if attributes.key?(:'amount_paid') self.amount_paid = attributes[:'amount_paid'] else self.amount_paid = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'period_start') self.period_start = attributes[:'period_start'] else self.period_start = nil end if attributes.key?(:'period_end') self.period_end = attributes[:'period_end'] else self.period_end = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'paid_at') self.paid_at = attributes[:'paid_at'] else self.paid_at = nil end if attributes.key?(:'hosted_invoice_url') self.hosted_invoice_url = attributes[:'hosted_invoice_url'] else self.hosted_invoice_url = nil end if attributes.key?(:'invoice_pdf') self.invoice_pdf = attributes[:'invoice_pdf'] else self.invoice_pdf = nil end end |
Instance Attribute Details
#amount_due ⇒ Object
Returns the value of attribute amount_due.
22 23 24 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 22 def amount_due @amount_due end |
#amount_paid ⇒ Object
Returns the value of attribute amount_paid.
24 25 26 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 24 def amount_paid @amount_paid end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 34 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 26 def currency @currency end |
#description ⇒ Object
Returns the value of attribute description.
28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 28 def description @description end |
#hosted_invoice_url ⇒ Object
Returns the value of attribute hosted_invoice_url.
38 39 40 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 38 def hosted_invoice_url @hosted_invoice_url end |
#invoice_pdf ⇒ Object
Returns the value of attribute invoice_pdf.
40 41 42 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 40 def invoice_pdf @invoice_pdf end |
#number ⇒ Object
Returns the value of attribute number.
18 19 20 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 18 def number @number end |
#paid_at ⇒ Object
Returns the value of attribute paid_at.
36 37 38 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 36 def paid_at @paid_at end |
#period_end ⇒ Object
Returns the value of attribute period_end.
32 33 34 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 32 def period_end @period_end end |
#period_start ⇒ Object
Returns the value of attribute period_start.
30 31 32 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 30 def period_start @period_start end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 20 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 43 def self.attribute_map { :'number' => :'number', :'status' => :'status', :'amount_due' => :'amount_due', :'amount_paid' => :'amount_paid', :'currency' => :'currency', :'description' => :'description', :'period_start' => :'period_start', :'period_end' => :'period_end', :'created_at' => :'created_at', :'paid_at' => :'paid_at', :'hosted_invoice_url' => :'hosted_invoice_url', :'invoice_pdf' => :'invoice_pdf' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 89 def self.openapi_nullable Set.new([ :'number', :'description', :'period_start', :'period_end', :'created_at', :'paid_at', :'hosted_invoice_url', :'invoice_pdf' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 71 def self.openapi_types { :'number' => :'String', :'status' => :'String', :'amount_due' => :'Integer', :'amount_paid' => :'Integer', :'currency' => :'String', :'description' => :'String', :'period_start' => :'String', :'period_end' => :'String', :'created_at' => :'String', :'paid_at' => :'String', :'hosted_invoice_url' => :'String', :'invoice_pdf' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 268 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && status == o.status && amount_due == o.amount_due && amount_paid == o.amount_paid && currency == o.currency && description == o.description && period_start == o.period_start && period_end == o.period_end && created_at == o.created_at && paid_at == o.paid_at && hosted_invoice_url == o.hosted_invoice_url && invoice_pdf == o.invoice_pdf end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 293 def hash [number, status, amount_due, amount_paid, currency, description, period_start, period_end, created_at, paid_at, hosted_invoice_url, invoice_pdf].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 193 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @amount_due.nil? invalid_properties.push('invalid value for "amount_due", amount_due cannot be nil.') end if @amount_paid.nil? invalid_properties.push('invalid value for "amount_paid", amount_paid cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/invoice.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @status.nil? return false if @amount_due.nil? return false if @amount_paid.nil? return false if @currency.nil? true end |