Class: SmplkitGeneratedClient::App::MetricAttributes

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetricAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::MetricAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::MetricAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'period_seconds')
    self.period_seconds = attributes[:'period_seconds']
  else
    self.period_seconds = nil
  end

  if attributes.key?(:'dimensions')
    if (value = attributes[:'dimensions']).is_a?(Hash)
      self.dimensions = value
    end
  end

  if attributes.key?(:'recorded_at')
    self.recorded_at = attributes[:'recorded_at']
  else
    self.recorded_at = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



30
31
32
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 30

def created_at
  @created_at
end

#dimensionsObject

Returns the value of attribute dimensions.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 26

def dimensions
  @dimensions
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 18

def name
  @name
end

#period_secondsObject

Returns the value of attribute period_seconds.



24
25
26
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 24

def period_seconds
  @period_seconds
end

#recorded_atObject

Returns the value of attribute recorded_at.



28
29
30
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 28

def recorded_at
  @recorded_at
end

#unitObject

Returns the value of attribute unit.



22
23
24
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 22

def unit
  @unit
end

#valueObject

Returns the value of attribute value.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 20

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'value' => :'value',
    :'unit' => :'unit',
    :'period_seconds' => :'period_seconds',
    :'dimensions' => :'dimensions',
    :'recorded_at' => :'recorded_at',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
73
74
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 69

def self.openapi_nullable
  Set.new([
    :'unit',
    :'created_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 56

def self.openapi_types
  {
    :'name' => :'String',
    :'value' => :'Value',
    :'unit' => :'String',
    :'period_seconds' => :'Integer',
    :'dimensions' => :'Hash<String, String>',
    :'recorded_at' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      value == o.value &&
      unit == o.unit &&
      period_seconds == o.period_seconds &&
      dimensions == o.dimensions &&
      recorded_at == o.recorded_at &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 228

def hash
  [name, value, unit, period_seconds, dimensions, recorded_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @period_seconds.nil?
    invalid_properties.push('invalid value for "period_seconds", period_seconds cannot be nil.')
  end

  if @recorded_at.nil?
    invalid_properties.push('invalid value for "recorded_at", recorded_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
161
162
163
164
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/metric_attributes.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @value.nil?
  return false if @period_seconds.nil?
  return false if @recorded_at.nil?
  true
end