Class: SmplkitGeneratedClient::App::Product
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::Product
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb
Overview
A smplkit product, with its plans, metered limits, and marketing copy.
Instance Attribute Summary collapse
-
#coming_soon ⇒ Object
When ‘true`, the product is listed but not yet available for subscription.
-
#description ⇒ Object
Long-form product description.
-
#display_name ⇒ Object
Human-readable product name.
-
#features ⇒ Object
Bullet-list feature highlights for the product.
-
#limits ⇒ Object
Map of limit key to limit definition for this product.
-
#metered_limits ⇒ Object
Limit keys on this product that are metered: each includes a monthly allotment in the plan price and bills per unit beyond it at the plan’s ‘overage_rates` rate, rather than capping hard.
-
#plans ⇒ Object
Map of plan key to plan definition for this product.
-
#tagline ⇒ Object
Short marketing tagline shown on plan-selection surfaces.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Product
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Product
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::Product` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::Product`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] else self.display_name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'tagline') self.tagline = attributes[:'tagline'] end if attributes.key?(:'features') if (value = attributes[:'features']).is_a?(Array) self.features = value end end if attributes.key?(:'coming_soon') self.coming_soon = attributes[:'coming_soon'] else self.coming_soon = false end if attributes.key?(:'limits') if (value = attributes[:'limits']).is_a?(Hash) self.limits = value end else self.limits = nil end if attributes.key?(:'metered_limits') if (value = attributes[:'metered_limits']).is_a?(Array) self.metered_limits = value end end if attributes.key?(:'plans') if (value = attributes[:'plans']).is_a?(Hash) self.plans = value end else self.plans = nil end end |
Instance Attribute Details
#coming_soon ⇒ Object
When ‘true`, the product is listed but not yet available for subscription.
32 33 34 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 32 def coming_soon @coming_soon end |
#description ⇒ Object
Long-form product description.
23 24 25 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 23 def description @description end |
#display_name ⇒ Object
Human-readable product name.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 20 def display_name @display_name end |
#features ⇒ Object
Bullet-list feature highlights for the product.
29 30 31 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 29 def features @features end |
#limits ⇒ Object
Map of limit key to limit definition for this product.
35 36 37 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 35 def limits @limits end |
#metered_limits ⇒ Object
Limit keys on this product that are metered: each includes a monthly allotment in the plan price and bills per unit beyond it at the plan’s ‘overage_rates` rate, rather than capping hard. Empty for products with no metered limits.
38 39 40 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 38 def metered_limits @metered_limits end |
#plans ⇒ Object
Map of plan key to plan definition for this product.
41 42 43 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 41 def plans @plans end |
#tagline ⇒ Object
Short marketing tagline shown on plan-selection surfaces.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 26 def tagline @tagline end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 44 def self.attribute_map { :'display_name' => :'display_name', :'description' => :'description', :'tagline' => :'tagline', :'features' => :'features', :'coming_soon' => :'coming_soon', :'limits' => :'limits', :'metered_limits' => :'metered_limits', :'plans' => :'plans' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 260 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 82 def self.openapi_nullable Set.new([ :'tagline', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 68 def self.openapi_types { :'display_name' => :'String', :'description' => :'String', :'tagline' => :'String', :'features' => :'Array<String>', :'coming_soon' => :'Boolean', :'limits' => :'Hash<String, LimitDefinition>', :'metered_limits' => :'Array<String>', :'plans' => :'Hash<String, PlanDefinition>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && display_name == o.display_name && description == o.description && tagline == o.tagline && features == o.features && coming_soon == o.coming_soon && limits == o.limits && metered_limits == o.metered_limits && plans == o.plans end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 253 def hash [display_name, description, tagline, features, coming_soon, limits, metered_limits, plans].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @display_name.nil? invalid_properties.push('invalid value for "display_name", display_name cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @limits.nil? invalid_properties.push('invalid value for "limits", limits cannot be nil.') end if @plans.nil? invalid_properties.push('invalid value for "plans", plans cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 282 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 188 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/product.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @display_name.nil? return false if @description.nil? return false if @limits.nil? return false if @plans.nil? true end |