Class: SmplkitGeneratedClient::App::ProductsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::ProductsApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/products_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ProductsApi
constructor
A new instance of ProductsApi.
-
#list_products(opts = {}) ⇒ ProductListResponse
List Products Return all flag-enabled products with their plans, limits, and marketing content.
-
#list_products_with_http_info(opts = {}) ⇒ Array<(ProductListResponse, Integer, Hash)>
List Products Return all flag-enabled products with their plans, limits, and marketing content.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProductsApi
Returns a new instance of ProductsApi.
19 20 21 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/products_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/products_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_products(opts = {}) ⇒ ProductListResponse
List Products Return all flag-enabled products with their plans, limits, and marketing content. Default sort is ‘display_name` ascending.
27 28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/products_api.rb', line 27 def list_products(opts = {}) data, _status_code, _headers = list_products_with_http_info(opts) data end |
#list_products_with_http_info(opts = {}) ⇒ Array<(ProductListResponse, Integer, Hash)>
List Products Return all flag-enabled products with their plans, limits, and marketing content. Default sort is `display_name` ascending.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/products_api.rb', line 37 def list_products_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProductsApi.list_products ...' end allowable_values = ["display_name", "-display_name", "id", "-id"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v1/products' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProductListResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"ProductsApi.list_products", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProductsApi#list_products\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |