Class: SmplkitGeneratedClient::App::SSOApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::SSOApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#claim_sso_domain(domain, sso_domain_request, opts = {}) ⇒ SSODomainResponse
Claim SSO Domain Claim a domain for SSO routing.
-
#claim_sso_domain_with_http_info(domain, sso_domain_request, opts = {}) ⇒ Array<(SSODomainResponse, Integer, Hash)>
Claim SSO Domain Claim a domain for SSO routing.
-
#delete_sso_connection(opts = {}) ⇒ nil
Delete SSO Connection Soft-delete the account’s SSO connection.
-
#delete_sso_connection_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete SSO Connection Soft-delete the account's SSO connection.
-
#get_sso_connection(opts = {}) ⇒ SSOConnectionResponse
Get SSO Connection Return the SSO connection for the current account, including computed Service Provider metadata.
-
#get_sso_connection_with_http_info(opts = {}) ⇒ Array<(SSOConnectionResponse, Integer, Hash)>
Get SSO Connection Return the SSO connection for the current account, including computed Service Provider metadata.
-
#initialize(api_client = ApiClient.default) ⇒ SSOApi
constructor
A new instance of SSOApi.
-
#list_sso_domains(opts = {}) ⇒ SSODomainListResponse
List SSO Domains List the domains claimed by the current account, including each row’s verification status.
-
#list_sso_domains_with_http_info(opts = {}) ⇒ Array<(SSODomainListResponse, Integer, Hash)>
List SSO Domains List the domains claimed by the current account, including each row's verification status.
-
#put_sso_connection(sso_connection_request, opts = {}) ⇒ SSOConnectionResponse
Create or Replace SSO Connection Create-or-replace the account’s SSO connection.
-
#put_sso_connection_with_http_info(sso_connection_request, opts = {}) ⇒ Array<(SSOConnectionResponse, Integer, Hash)>
Create or Replace SSO Connection Create-or-replace the account's SSO connection.
-
#release_sso_domain(domain, opts = {}) ⇒ nil
Release SSO Domain Release a previously-claimed SSO domain.
-
#release_sso_domain_with_http_info(domain, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Release SSO Domain Release a previously-claimed SSO domain.
-
#verify_sso_domain(domain, opts = {}) ⇒ SSODomainResponse
Verify SSO Domain Run the DNS TXT check for a claimed domain.
-
#verify_sso_domain_with_http_info(domain, opts = {}) ⇒ Array<(SSODomainResponse, Integer, Hash)>
Verify SSO Domain Run the DNS TXT check for a claimed domain.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#claim_sso_domain(domain, sso_domain_request, opts = {}) ⇒ SSODomainResponse
Claim SSO Domain Claim a domain for SSO routing. Idempotent — re-claiming a domain already held by the account is a no-op success. The response includes the DNS TXT token to publish.
28 29 30 31 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 28 def claim_sso_domain(domain, sso_domain_request, opts = {}) data, _status_code, _headers = claim_sso_domain_with_http_info(domain, sso_domain_request, opts) data end |
#claim_sso_domain_with_http_info(domain, sso_domain_request, opts = {}) ⇒ Array<(SSODomainResponse, Integer, Hash)>
Claim SSO Domain Claim a domain for SSO routing. Idempotent — re-claiming a domain already held by the account is a no-op success. The response includes the DNS TXT token to publish.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 39 def claim_sso_domain_with_http_info(domain, sso_domain_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.claim_sso_domain ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling SSOApi.claim_sso_domain" end # verify the required parameter 'sso_domain_request' is set if @api_client.config.client_side_validation && sso_domain_request.nil? fail ArgumentError, "Missing the required parameter 'sso_domain_request' when calling SSOApi.claim_sso_domain" end # resource path local_var_path = '/api/v1/accounts/current/sso_domains/{domain}'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(sso_domain_request) # return_type return_type = opts[:debug_return_type] || 'SSODomainResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.claim_sso_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#claim_sso_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_sso_connection(opts = {}) ⇒ nil
Delete SSO Connection Soft-delete the account’s SSO connection. Domains are preserved.
100 101 102 103 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 100 def delete_sso_connection(opts = {}) delete_sso_connection_with_http_info(opts) nil end |
#delete_sso_connection_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete SSO Connection Soft-delete the account's SSO connection. Domains are preserved.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 109 def delete_sso_connection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.delete_sso_connection ...' end # resource path local_var_path = '/api/v1/accounts/current/sso_connection' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.delete_sso_connection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#delete_sso_connection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_sso_connection(opts = {}) ⇒ SSOConnectionResponse
Get SSO Connection Return the SSO connection for the current account, including computed Service Provider metadata. Returns ‘404` when no connection has been configured.
157 158 159 160 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 157 def get_sso_connection(opts = {}) data, _status_code, _headers = get_sso_connection_with_http_info(opts) data end |
#get_sso_connection_with_http_info(opts = {}) ⇒ Array<(SSOConnectionResponse, Integer, Hash)>
Get SSO Connection Return the SSO connection for the current account, including computed Service Provider metadata. Returns `404` when no connection has been configured.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 166 def get_sso_connection_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.get_sso_connection ...' end # resource path local_var_path = '/api/v1/accounts/current/sso_connection' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SSOConnectionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.get_sso_connection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#get_sso_connection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_sso_domains(opts = {}) ⇒ SSODomainListResponse
List SSO Domains List the domains claimed by the current account, including each row’s verification status.
214 215 216 217 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 214 def list_sso_domains(opts = {}) data, _status_code, _headers = list_sso_domains_with_http_info(opts) data end |
#list_sso_domains_with_http_info(opts = {}) ⇒ Array<(SSODomainListResponse, Integer, Hash)>
List SSO Domains List the domains claimed by the current account, including each row's verification status.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 223 def list_sso_domains_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.list_sso_domains ...' end # resource path local_var_path = '/api/v1/accounts/current/sso_domains' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SSODomainListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.list_sso_domains", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#list_sso_domains\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_sso_connection(sso_connection_request, opts = {}) ⇒ SSOConnectionResponse
Create or Replace SSO Connection Create-or-replace the account’s SSO connection. The OIDC ‘client_secret` is write-only; supply it on first creation, omit on subsequent updates to retain the stored value.
272 273 274 275 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 272 def put_sso_connection(sso_connection_request, opts = {}) data, _status_code, _headers = put_sso_connection_with_http_info(sso_connection_request, opts) data end |
#put_sso_connection_with_http_info(sso_connection_request, opts = {}) ⇒ Array<(SSOConnectionResponse, Integer, Hash)>
Create or Replace SSO Connection Create-or-replace the account's SSO connection. The OIDC `client_secret` is write-only; supply it on first creation, omit on subsequent updates to retain the stored value.
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 282 def put_sso_connection_with_http_info(sso_connection_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.put_sso_connection ...' end # verify the required parameter 'sso_connection_request' is set if @api_client.config.client_side_validation && sso_connection_request.nil? fail ArgumentError, "Missing the required parameter 'sso_connection_request' when calling SSOApi.put_sso_connection" end # resource path local_var_path = '/api/v1/accounts/current/sso_connection' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(sso_connection_request) # return_type return_type = opts[:debug_return_type] || 'SSOConnectionResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.put_sso_connection", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#put_sso_connection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#release_sso_domain(domain, opts = {}) ⇒ nil
Release SSO Domain Release a previously-claimed SSO domain.
340 341 342 343 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 340 def release_sso_domain(domain, opts = {}) release_sso_domain_with_http_info(domain, opts) nil end |
#release_sso_domain_with_http_info(domain, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Release SSO Domain Release a previously-claimed SSO domain.
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 350 def release_sso_domain_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.release_sso_domain ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling SSOApi.release_sso_domain" end # resource path local_var_path = '/api/v1/accounts/current/sso_domains/{domain}'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.release_sso_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#release_sso_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#verify_sso_domain(domain, opts = {}) ⇒ SSODomainResponse
Verify SSO Domain Run the DNS TXT check for a claimed domain. Returns the updated resource on success. Returns ‘409` if a different account has already verified this domain. Returns `422` when the DNS TXT record has not yet been published or does not match the expected token.
403 404 405 406 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 403 def verify_sso_domain(domain, opts = {}) data, _status_code, _headers = verify_sso_domain_with_http_info(domain, opts) data end |
#verify_sso_domain_with_http_info(domain, opts = {}) ⇒ Array<(SSODomainResponse, Integer, Hash)>
Verify SSO Domain Run the DNS TXT check for a claimed domain. Returns the updated resource on success. Returns `409` if a different account has already verified this domain. Returns `422` when the DNS TXT record has not yet been published or does not match the expected token.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/sso_api.rb', line 413 def verify_sso_domain_with_http_info(domain, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SSOApi.verify_sso_domain ...' end # verify the required parameter 'domain' is set if @api_client.config.client_side_validation && domain.nil? fail ArgumentError, "Missing the required parameter 'domain' when calling SSOApi.verify_sso_domain" end # resource path local_var_path = '/api/v1/accounts/current/sso_domains/{domain}/actions/verify'.sub('{domain}', CGI.escape(domain.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SSODomainResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"SSOApi.verify_sso_domain", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SSOApi#verify_sso_domain\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |