Class: SmplkitGeneratedClient::App::SubscriptionAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::App::SubscriptionAttributes
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb
Instance Attribute Summary collapse
-
#bundle ⇒ Object
Returns the value of attribute bundle.
-
#client_secret ⇒ Object
Returns the value of attribute client_secret.
-
#comped ⇒ Object
Returns the value of attribute comped.
-
#current_period_end ⇒ Object
Returns the value of attribute current_period_end.
-
#plan ⇒ Object
Returns the value of attribute plan.
-
#product ⇒ Object
Returns the value of attribute product.
-
#status ⇒ Object
Returns the value of attribute status.
-
#stripe_managed ⇒ Object
Returns the value of attribute stripe_managed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionAttributes
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'product') self.product = attributes[:'product'] else self.product = nil end if attributes.key?(:'plan') self.plan = attributes[:'plan'] else self.plan = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'comped') self.comped = attributes[:'comped'] else self.comped = nil end if attributes.key?(:'stripe_managed') self.stripe_managed = attributes[:'stripe_managed'] else self.stripe_managed = nil end if attributes.key?(:'bundle') self.bundle = attributes[:'bundle'] end if attributes.key?(:'current_period_end') self.current_period_end = attributes[:'current_period_end'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end end |
Instance Attribute Details
#bundle ⇒ Object
Returns the value of attribute bundle.
28 29 30 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 28 def bundle @bundle end |
#client_secret ⇒ Object
Returns the value of attribute client_secret.
32 33 34 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 32 def client_secret @client_secret end |
#comped ⇒ Object
Returns the value of attribute comped.
24 25 26 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 24 def comped @comped end |
#current_period_end ⇒ Object
Returns the value of attribute current_period_end.
30 31 32 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 30 def current_period_end @current_period_end end |
#plan ⇒ Object
Returns the value of attribute plan.
20 21 22 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 20 def plan @plan end |
#product ⇒ Object
Returns the value of attribute product.
18 19 20 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 18 def product @product end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 22 def status @status end |
#stripe_managed ⇒ Object
Returns the value of attribute stripe_managed.
26 27 28 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 26 def stripe_managed @stripe_managed end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 35 def self.attribute_map { :'product' => :'product', :'plan' => :'plan', :'status' => :'status', :'comped' => :'comped', :'stripe_managed' => :'stripe_managed', :'bundle' => :'bundle', :'current_period_end' => :'current_period_end', :'client_secret' => :'client_secret' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 77 78 79 80 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 73 def self.openapi_nullable Set.new([ :'status', :'bundle', :'current_period_end', :'client_secret' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 59 def self.openapi_types { :'product' => :'String', :'plan' => :'String', :'status' => :'String', :'comped' => :'Boolean', :'stripe_managed' => :'Boolean', :'bundle' => :'String', :'current_period_end' => :'String', :'client_secret' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 216 def ==(o) return true if self.equal?(o) self.class == o.class && product == o.product && plan == o.plan && status == o.status && comped == o.comped && stripe_managed == o.stripe_managed && bundle == o.bundle && current_period_end == o.current_period_end && client_secret == o.client_secret end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 237 def hash [product, plan, status, comped, stripe_managed, bundle, current_period_end, client_secret].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @product.nil? invalid_properties.push('invalid value for "product", product cannot be nil.') end if @plan.nil? invalid_properties.push('invalid value for "plan", plan cannot be nil.') end if @comped.nil? invalid_properties.push('invalid value for "comped", comped cannot be nil.') end if @stripe_managed.nil? invalid_properties.push('invalid value for "stripe_managed", stripe_managed cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_attributes.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @product.nil? return false if @plan.nil? return false if @comped.nil? return false if @stripe_managed.nil? true end |