Class: SmplkitGeneratedClient::App::SubscriptionItemResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb

Overview

One product enrollment as exposed in subscription responses.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionItemResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::SubscriptionItemResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::SubscriptionItemResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  else
    self.product = nil
  end

  if attributes.key?(:'plan')
    self.plan = attributes[:'plan']
  else
    self.plan = nil
  end

  if attributes.key?(:'price_monthly_cents')
    self.price_monthly_cents = attributes[:'price_monthly_cents']
  else
    self.price_monthly_cents = nil
  end

  if attributes.key?(:'pending_plan_change')
    self.pending_plan_change = attributes[:'pending_plan_change']
  end

  if attributes.key?(:'scheduled_change_effective_at')
    self.scheduled_change_effective_at = attributes[:'scheduled_change_effective_at']
  end
end

Instance Attribute Details

#idObject

Unique identifier for this enrollment.



20
21
22
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 20

def id
  @id
end

#pending_plan_changeObject

When a plan change is scheduled for the end of the current billing period, this is the plan that will take effect. Otherwise ‘null`. The value `FREE` indicates the enrollment will be dropped.



32
33
34
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 32

def pending_plan_change
  @pending_plan_change
end

#planObject

Current plan for this product (e.g. ‘STANDARD`, `PRO`).



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 26

def plan
  @plan
end

#price_monthly_centsObject

Monthly list price for this enrollment, in cents. This value is locked at the time the enrollment was created or last had its plan changed; subsequent changes to the public price list do not affect this enrollment until the customer themselves changes their plan.



29
30
31
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 29

def price_monthly_cents
  @price_monthly_cents
end

#productObject

Product key (e.g. ‘audit`, `config`, `flags`, `logging`).



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 23

def product
  @product
end

#scheduled_change_effective_atObject

ISO-8601 timestamp at which the pending plan change takes effect. Matches the subscription’s ‘current_period_end`.



35
36
37
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 35

def scheduled_change_effective_at
  @scheduled_change_effective_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 38

def self.attribute_map
  {
    :'id' => :'id',
    :'product' => :'product',
    :'plan' => :'plan',
    :'price_monthly_cents' => :'price_monthly_cents',
    :'pending_plan_change' => :'pending_plan_change',
    :'scheduled_change_effective_at' => :'scheduled_change_effective_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 72

def self.openapi_nullable
  Set.new([
    :'pending_plan_change',
    :'scheduled_change_effective_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'product' => :'String',
    :'plan' => :'String',
    :'price_monthly_cents' => :'Integer',
    :'pending_plan_change' => :'String',
    :'scheduled_change_effective_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      product == o.product &&
      plan == o.plan &&
      price_monthly_cents == o.price_monthly_cents &&
      pending_plan_change == o.pending_plan_change &&
      scheduled_change_effective_at == o.scheduled_change_effective_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 224

def hash
  [id, product, plan, price_monthly_cents, pending_plan_change, scheduled_change_effective_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @product.nil?
    invalid_properties.push('invalid value for "product", product cannot be nil.')
  end

  if @plan.nil?
    invalid_properties.push('invalid value for "plan", plan cannot be nil.')
  end

  if @price_monthly_cents.nil?
    invalid_properties.push('invalid value for "price_monthly_cents", price_monthly_cents cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/subscription_item_response.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @product.nil?
  return false if @plan.nil?
  return false if @price_monthly_cents.nil?
  true
end