Class: SmplkitGeneratedClient::App::User

Inherits:
ApiModelBase show all
Defined in:
lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::App::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::App::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  else
    self.display_name = nil
  end

  if attributes.key?(:'profile_pic')
    self.profile_pic = attributes[:'profile_pic']
  end

  if attributes.key?(:'avatar_url')
    self.avatar_url = attributes[:'avatar_url']
  end

  if attributes.key?(:'auth_provider')
    self.auth_provider = attributes[:'auth_provider']
  end

  if attributes.key?(:'email_verified')
    self.email_verified = attributes[:'email_verified']
  else
    self.email_verified = false
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#accountObject

Account UUID



36
37
38
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 36

def 
  @account
end

#auth_providerObject

Returns the value of attribute auth_provider.



28
29
30
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 28

def auth_provider
  @auth_provider
end

#avatar_urlObject

Server-computed “data:“ URL when an OIDC provider supplied a profile picture. Null otherwise — callers should fall back to Gravatar or initials.



26
27
28
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 26

def avatar_url
  @avatar_url
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 38

def created_at
  @created_at
end

#display_nameObject

Returns the value of attribute display_name.



21
22
23
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 21

def display_name
  @display_name
end

#emailObject

User’s email address



19
20
21
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 19

def email
  @email
end

#email_verifiedObject

Returns the value of attribute email_verified.



30
31
32
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 30

def email_verified
  @email_verified
end

#profile_picObject

Returns the value of attribute profile_pic.



23
24
25
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 23

def profile_pic
  @profile_pic
end

#roleObject

Role in current account context



33
34
35
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 33

def role
  @role
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 41

def self.attribute_map
  {
    :'email' => :'email',
    :'display_name' => :'display_name',
    :'profile_pic' => :'profile_pic',
    :'avatar_url' => :'avatar_url',
    :'auth_provider' => :'auth_provider',
    :'email_verified' => :'email_verified',
    :'role' => :'role',
    :'account' => :'account',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 251

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
89
90
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 81

def self.openapi_nullable
  Set.new([
    :'profile_pic',
    :'avatar_url',
    :'auth_provider',
    :'role',
    :'account',
    :'created_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 66

def self.openapi_types
  {
    :'email' => :'String',
    :'display_name' => :'String',
    :'profile_pic' => :'String',
    :'avatar_url' => :'String',
    :'auth_provider' => :'String',
    :'email_verified' => :'Boolean',
    :'role' => :'String',
    :'account' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      display_name == o.display_name &&
      profile_pic == o.profile_pic &&
      avatar_url == o.avatar_url &&
      auth_provider == o.auth_provider &&
      email_verified == o.email_verified &&
      role == o.role &&
       == o. &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 238

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 244

def hash
  [email, display_name, profile_pic, avatar_url, auth_provider, email_verified, role, , created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @display_name.nil?
    invalid_properties.push('invalid value for "display_name", display_name cannot be nil.')
  end

  if @display_name.to_s.length > 255
    invalid_properties.push('invalid value for "display_name", the character length must be smaller than or equal to 255.')
  end

  if !@profile_pic.nil? && @profile_pic.to_s.length > 2048
    invalid_properties.push('invalid value for "profile_pic", the character length must be smaller than or equal to 2048.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 273

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
184
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/models/user.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if @display_name.nil?
  return false if @display_name.to_s.length > 255
  return false if !@profile_pic.nil? && @profile_pic.to_s.length > 2048
  true
end