Class: SmplkitGeneratedClient::App::UsersApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::App::UsersApi
- Defined in:
- lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_current_user(opts = {}) ⇒ UserResponse
Get Current User Return the currently authenticated user.
-
#get_current_user_with_http_info(opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get Current User Return the currently authenticated user.
-
#get_user(id, opts = {}) ⇒ UserResponse
Get User Return a user by id.
-
#get_user_settings(opts = {}) ⇒ Hash<String, Object>
Get User Settings Return the current user’s settings as plain JSON.
-
#get_user_settings_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get User Settings Return the current user's settings as plain JSON.
-
#get_user_with_http_info(id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get User Return a user by id.
-
#initialize(api_client = ApiClient.default) ⇒ UsersApi
constructor
A new instance of UsersApi.
-
#list_users(opts = {}) ⇒ UserListResponse
List Users List users in the authenticated account.
-
#list_users_with_http_info(opts = {}) ⇒ Array<(UserListResponse, Integer, Hash)>
List Users List users in the authenticated account.
-
#put_user_settings(opts = {}) ⇒ Hash<String, Object>
Update User Settings Replace the current user’s settings with the provided JSON object.
-
#put_user_settings_key(key, opts = {}) ⇒ Hash<String, Object>
Update User Setting by Key Set a single key in the current user’s settings.
-
#put_user_settings_key_with_http_info(key, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update User Setting by Key Set a single key in the current user's settings.
-
#put_user_settings_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update User Settings Replace the current user's settings with the provided JSON object.
-
#remove_user(id, opts = {}) ⇒ nil
Remove User Remove a user from the account.
-
#remove_user_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove User Remove a user from the account.
-
#update_current_user(user_response, opts = {}) ⇒ UserResponse
Update Current User Update the currently authenticated user’s profile.
-
#update_current_user_with_http_info(user_response, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update Current User Update the currently authenticated user's profile.
-
#update_user_role(id, user_response, opts = {}) ⇒ UserResponse
Update User Role Update a user’s role in the account.
-
#update_user_role_with_http_info(id, user_response, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update User Role Update a user's role in the account.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_current_user(opts = {}) ⇒ UserResponse
Get Current User Return the currently authenticated user. “role“ and “account“ are populated when the user has a membership; both are null when the caller is authenticated but has no account yet — e.g. a returning user who has just accepted an invitation email.
26 27 28 29 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 26 def get_current_user(opts = {}) data, _status_code, _headers = get_current_user_with_http_info(opts) data end |
#get_current_user_with_http_info(opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get Current User Return the currently authenticated user. ``role`` and ``account`` are populated when the user has a membership; both are null when the caller is authenticated but has no account yet — e.g. a returning user who has just accepted an invitation email.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 35 def get_current_user_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_current_user ...' end # resource path local_var_path = '/api/v1/users/current' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.get_current_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_current_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user(id, opts = {}) ⇒ UserResponse
Get User Return a user by id.
84 85 86 87 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 84 def get_user(id, opts = {}) data, _status_code, _headers = get_user_with_http_info(id, opts) data end |
#get_user_settings(opts = {}) ⇒ Hash<String, Object>
Get User Settings Return the current user’s settings as plain JSON.
146 147 148 149 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 146 def get_user_settings(opts = {}) data, _status_code, _headers = get_user_settings_with_http_info(opts) data end |
#get_user_settings_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Get User Settings Return the current user's settings as plain JSON.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 155 def get_user_settings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user_settings ...' end # resource path local_var_path = '/api/v1/users/current/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.get_user_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user_with_http_info(id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get User Return a user by id.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 94 def get_user_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UsersApi.get_user" end # resource path local_var_path = '/api/v1/users/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.get_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_users(opts = {}) ⇒ UserListResponse
List Users List users in the authenticated account.
208 209 210 211 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 208 def list_users(opts = {}) data, _status_code, _headers = list_users_with_http_info(opts) data end |
#list_users_with_http_info(opts = {}) ⇒ Array<(UserListResponse, Integer, Hash)>
List Users List users in the authenticated account.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 222 def list_users_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.list_users ...' end if @api_client.config.client_side_validation && !opts[:'page_number'].nil? && opts[:'page_number'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_number"]" when calling UsersApi.list_users, must be greater than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 200 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling UsersApi.list_users, must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling UsersApi.list_users, must be greater than or equal to 1.' end # resource path local_var_path = '/api/v1/users' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[account]'] = opts[:'filter_account'] if !opts[:'filter_account'].nil? query_params[:'filter[email]'] = opts[:'filter_email'] if !opts[:'filter_email'].nil? query_params[:'filter[search]'] = opts[:'filter_search'] if !opts[:'filter_search'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.list_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#list_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_user_settings(opts = {}) ⇒ Hash<String, Object>
Update User Settings Replace the current user’s settings with the provided JSON object.
287 288 289 290 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 287 def put_user_settings(opts = {}) data, _status_code, _headers = put_user_settings_with_http_info(opts) data end |
#put_user_settings_key(key, opts = {}) ⇒ Hash<String, Object>
Update User Setting by Key Set a single key in the current user’s settings. The key is stored as a flat literal key (dot-notation is NOT expanded to nested paths). Returns the full updated settings object.
345 346 347 348 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 345 def put_user_settings_key(key, opts = {}) data, _status_code, _headers = put_user_settings_key_with_http_info(key, opts) data end |
#put_user_settings_key_with_http_info(key, opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update User Setting by Key Set a single key in the current user's settings. The key is stored as a flat literal key (dot-notation is NOT expanded to nested paths). Returns the full updated settings object.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 355 def put_user_settings_key_with_http_info(key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.put_user_settings_key ...' end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling UsersApi.put_user_settings_key" end # resource path local_var_path = '/api/v1/users/current/settings/{key}'.sub('{key}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.put_user_settings_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#put_user_settings_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_user_settings_with_http_info(opts = {}) ⇒ Array<(Hash<String, Object>, Integer, Hash)>
Update User Settings Replace the current user's settings with the provided JSON object.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 296 def put_user_settings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.put_user_settings ...' end # resource path local_var_path = '/api/v1/users/current/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, Object>' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.put_user_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#put_user_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_user(id, opts = {}) ⇒ nil
Remove User Remove a user from the account.
408 409 410 411 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 408 def remove_user(id, opts = {}) remove_user_with_http_info(id, opts) nil end |
#remove_user_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove User Remove a user from the account.
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 418 def remove_user_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.remove_user ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UsersApi.remove_user" end # resource path local_var_path = '/api/v1/users/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.remove_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#remove_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_current_user(user_response, opts = {}) ⇒ UserResponse
Update Current User Update the currently authenticated user’s profile.
471 472 473 474 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 471 def update_current_user(user_response, opts = {}) data, _status_code, _headers = update_current_user_with_http_info(user_response, opts) data end |
#update_current_user_with_http_info(user_response, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update Current User Update the currently authenticated user's profile.
481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 481 def update_current_user_with_http_info(user_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_current_user ...' end # verify the required parameter 'user_response' is set if @api_client.config.client_side_validation && user_response.nil? fail ArgumentError, "Missing the required parameter 'user_response' when calling UsersApi.update_current_user" end # resource path local_var_path = '/api/v1/users/current' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_response) # return_type return_type = opts[:debug_return_type] || 'UserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.update_current_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_current_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user_role(id, user_response, opts = {}) ⇒ UserResponse
Update User Role Update a user’s role in the account.
540 541 542 543 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 540 def update_user_role(id, user_response, opts = {}) data, _status_code, _headers = update_user_role_with_http_info(id, user_response, opts) data end |
#update_user_role_with_http_info(id, user_response, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update User Role Update a user's role in the account.
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 |
# File 'lib/smplkit/_generated/app/lib/smplkit_app_client/api/users_api.rb', line 551 def update_user_role_with_http_info(id, user_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user_role ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling UsersApi.update_user_role" end # verify the required parameter 'user_response' is set if @api_client.config.client_side_validation && user_response.nil? fail ArgumentError, "Missing the required parameter 'user_response' when calling UsersApi.update_user_role" end # resource path local_var_path = '/api/v1/users/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_response) # return_type return_type = opts[:debug_return_type] || 'UserResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"UsersApi.update_user_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |