Class: SmplkitGeneratedClient::Audit::ActionsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Audit::ActionsApi
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ ActionsApi
constructor
A new instance of ActionsApi.
-
#list_actions(opts = {}) ⇒ ActionListResponse
List Actions List the distinct “action“ slugs seen in the account.
-
#list_actions_with_http_info(opts = {}) ⇒ Array<(ActionListResponse, Integer, Hash)>
List Actions List the distinct ``action`` slugs seen in the account.
-
#list_resource_types(opts = {}) ⇒ ResourceTypeListResponse
List Resource Types List the distinct “resource_type“ slugs seen in the account.
-
#list_resource_types_with_http_info(opts = {}) ⇒ Array<(ResourceTypeListResponse, Integer, Hash)>
List Resource Types List the distinct ``resource_type`` slugs seen in the account.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ActionsApi
Returns a new instance of ActionsApi.
19 20 21 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_actions(opts = {}) ⇒ ActionListResponse
List Actions List the distinct “action“ slugs seen in the account. Without “filter“, returns one row per distinct action — the same action may have been recorded with multiple resource types and the unfiltered dropdown shows it once. With “filter“, returns the actions seen with that specific resource type, powering the Activity tab’s cascading filter behavior.
29 30 31 32 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 29 def list_actions(opts = {}) data, _status_code, _headers = list_actions_with_http_info(opts) data end |
#list_actions_with_http_info(opts = {}) ⇒ Array<(ActionListResponse, Integer, Hash)>
List Actions List the distinct ``action`` slugs seen in the account. Without ``filter``, returns one row per distinct action — the same action may have been recorded with multiple resource types and the unfiltered dropdown shows it once. With ``filter``, returns the actions seen with that specific resource type, powering the Activity tab's cascading filter behavior.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 41 def list_actions_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ActionsApi.list_actions ...' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ActionsApi.list_actions, must be greater than or equal to 1.' end # resource path local_var_path = '/api/v1/actions' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[resource_type]'] = opts[:'filter_resource_type'] if !opts[:'filter_resource_type'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[after]'] = opts[:'page_after'] if !opts[:'page_after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ActionListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ActionsApi.list_actions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ActionsApi#list_actions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_resource_types(opts = {}) ⇒ ResourceTypeListResponse
List Resource Types List the distinct “resource_type“ slugs seen in the account. Each row’s “id“ is the slug itself, mirroring the smplkit convention of using customer-provided identifiers as the public-facing resource id (ADR-014).
98 99 100 101 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 98 def list_resource_types(opts = {}) data, _status_code, _headers = list_resource_types_with_http_info(opts) data end |
#list_resource_types_with_http_info(opts = {}) ⇒ Array<(ResourceTypeListResponse, Integer, Hash)>
List Resource Types List the distinct ``resource_type`` slugs seen in the account. Each row's ``id`` is the slug itself, mirroring the smplkit convention of using customer-provided identifiers as the public-facing resource id (ADR-014).
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/actions_api.rb', line 109 def list_resource_types_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ActionsApi.list_resource_types ...' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling ActionsApi.list_resource_types, must be greater than or equal to 1.' end # resource path local_var_path = '/api/v1/resource_types' # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[after]'] = opts[:'page_after'] if !opts[:'page_after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ResourceTypeListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ActionsApi.list_resource_types", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ActionsApi#list_resource_types\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |