Class: SmplkitGeneratedClient::Audit::EventsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Audit::EventsApi
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_event(event_id, opts = {}) ⇒ EventResponse
Get Event Retrieve a single audit event by id.
-
#get_event_with_http_info(event_id, opts = {}) ⇒ Array<(EventResponse, Integer, Hash)>
Get Event Retrieve a single audit event by id.
-
#initialize(api_client = ApiClient.default) ⇒ EventsApi
constructor
A new instance of EventsApi.
-
#list_events(opts = {}) ⇒ EventListResponse
List Events List audit events for the authenticated account.
-
#list_events_with_http_info(opts = {}) ⇒ Array<(EventListResponse, Integer, Hash)>
List Events List audit events for the authenticated account.
-
#record_event(event_response, opts = {}) ⇒ EventResponse
Record Event Record an audit event for the authenticated account.
-
#record_event_with_http_info(event_response, opts = {}) ⇒ Array<(EventResponse, Integer, Hash)>
Record Event Record an audit event for the authenticated account.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_event(event_id, opts = {}) ⇒ EventResponse
Get Event Retrieve a single audit event by id. Returns 404 if no event with that id exists in the caller’s account — RLS enforces tenant isolation; this endpoint never leaks the existence of another tenant’s event.
27 28 29 30 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 27 def get_event(event_id, opts = {}) data, _status_code, _headers = get_event_with_http_info(event_id, opts) data end |
#get_event_with_http_info(event_id, opts = {}) ⇒ Array<(EventResponse, Integer, Hash)>
Get Event Retrieve a single audit event by id. Returns 404 if no event with that id exists in the caller's account — RLS enforces tenant isolation; this endpoint never leaks the existence of another tenant's event.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 37 def get_event_with_http_info(event_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.get_event ...' end # verify the required parameter 'event_id' is set if @api_client.config.client_side_validation && event_id.nil? fail ArgumentError, "Missing the required parameter 'event_id' when calling EventsApi.get_event" end # resource path local_var_path = '/api/v1/events/{event_id}'.sub('{event_id}', CGI.escape(event_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EventsApi.get_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#get_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_events(opts = {}) ⇒ EventListResponse
97 98 99 100 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 97 def list_events(opts = {}) data, _status_code, _headers = list_events_with_http_info(opts) data end |
#list_events_with_http_info(opts = {}) ⇒ Array<(EventListResponse, Integer, Hash)>
List Events List audit events for the authenticated account. Default sort is ``-created_at``; cursor pagination via ``page`` (the opaque cursor returned in ``links.next``). Filters are exact-match except ``filter`` which uses the platform's range notation (``[2026-01-01T00:00:00Z,*)``).
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 114 def list_events_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.list_events ...' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling EventsApi.list_events, must be greater than or equal to 1.' end # resource path local_var_path = '/api/v1/events' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[occurred_at]'] = opts[:'filter_occurred_at'] if !opts[:'filter_occurred_at'].nil? query_params[:'filter[actor_type]'] = opts[:'filter_actor_type'] if !opts[:'filter_actor_type'].nil? query_params[:'filter[actor_id]'] = opts[:'filter_actor_id'] if !opts[:'filter_actor_id'].nil? query_params[:'filter[action]'] = opts[:'filter_action'] if !opts[:'filter_action'].nil? query_params[:'filter[resource_type]'] = opts[:'filter_resource_type'] if !opts[:'filter_resource_type'].nil? query_params[:'filter[resource_id]'] = opts[:'filter_resource_id'] if !opts[:'filter_resource_id'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[after]'] = opts[:'page_after'] if !opts[:'page_after'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EventsApi.list_events", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#list_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#record_event(event_response, opts = {}) ⇒ EventResponse
Record Event Record an audit event for the authenticated account. Returns “201 Created“ on first write, “200 OK“ if the request was a duplicate (matched by “Idempotency-Key“ or auto-derived key). Customers may not emit events whose “resource_type“ starts with “smpl.“ — that namespace is reserved for smplkit-emitted events about platform resources.
176 177 178 179 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 176 def record_event(event_response, opts = {}) data, _status_code, _headers = record_event_with_http_info(event_response, opts) data end |
#record_event_with_http_info(event_response, opts = {}) ⇒ Array<(EventResponse, Integer, Hash)>
Record Event Record an audit event for the authenticated account. Returns ``201 Created`` on first write, ``200 OK`` if the request was a duplicate (matched by ``Idempotency-Key`` or auto-derived key). Customers may not emit events whose ``resource_type`` starts with ``smpl.`` — that namespace is reserved for smplkit-emitted events about platform resources.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/api/events_api.rb', line 187 def record_event_with_http_info(event_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.record_event ...' end # verify the required parameter 'event_response' is set if @api_client.config.client_side_validation && event_response.nil? fail ArgumentError, "Missing the required parameter 'event_response' when calling EventsApi.record_event" end # resource path local_var_path = '/api/v1/events' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'Idempotency-Key'] = opts[:'idempotency_key'] if !opts[:'idempotency_key'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(event_response) # return_type return_type = opts[:debug_return_type] || 'EventResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"EventsApi.record_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#record_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |