Class: SmplkitGeneratedClient::Audit::ForwarderHttp
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Audit::ForwarderHttp
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb
Overview
HTTP request configuration used to deliver an event to the destination.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#body ⇒ Object
Request body sent to the destination.
-
#headers ⇒ Object
HTTP headers attached to each delivery request.
-
#method ⇒ Object
HTTP method used when delivering an event.
-
#success_status ⇒ Object
HTTP response status that indicates a successful delivery.
-
#url ⇒ Object
Destination URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForwarderHttp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ForwarderHttp
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::ForwarderHttp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::ForwarderHttp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = 'POST' end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Array) self.headers = value end end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'success_status') self.success_status = attributes[:'success_status'] else self.success_status = '2xx' end end |
Instance Attribute Details
#body ⇒ Object
Request body sent to the destination. If omitted, the event JSON is sent as the body.
29 30 31 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 29 def body @body end |
#headers ⇒ Object
HTTP headers attached to each delivery request.
26 27 28 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 26 def headers @headers end |
#method ⇒ Object
HTTP method used when delivering an event.
20 21 22 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 20 def method @method end |
#success_status ⇒ Object
HTTP response status that indicates a successful delivery. Either a specific status code (e.g. ‘200`, `204`) or a status class (`1xx`, `2xx`, `3xx`, `4xx`, `5xx`).
32 33 34 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 32 def success_status @success_status end |
#url ⇒ Object
Destination URL.
23 24 25 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 23 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 57 def self.attribute_map { :'method' => :'method', :'url' => :'url', :'headers' => :'headers', :'body' => :'body', :'success_status' => :'success_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 93 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 89 def self.openapi_nullable Set.new([ :'body', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 78 def self.openapi_types { :'method' => :'String', :'url' => :'String', :'headers' => :'Array<HttpHeader>', :'body' => :'String', :'success_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && method == o.method && url == o.url && headers == o.headers && body == o.body && success_status == o.success_status end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 254 def hash [method, url, headers, body, success_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @url.to_s.length > 2048 invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2048.') end if @url.to_s.length < 1 invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.') end if !@body.nil? && @body.to_s.length > 65536 invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 65536.') end if !@success_status.nil? && @success_status.to_s.length > 3 invalid_properties.push('invalid value for "success_status", the character length must be smaller than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' method_validator = EnumAttributeValidator.new('String', ["GET", "POST", "PUT", "PATCH", "DELETE"]) return false unless method_validator.valid?(@method) return false if @url.nil? return false if @url.to_s.length > 2048 return false if @url.to_s.length < 1 return false if !@body.nil? && @body.to_s.length > 65536 return false if !@success_status.nil? && @success_status.to_s.length > 3 true end |