Class: SmplkitGeneratedClient::Audit::ForwarderHttp
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Audit::ForwarderHttp
- Defined in:
- lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb
Overview
The destination HTTP request shape stored encrypted on a forwarder. “success_status“ is either a single integer status (e.g. “200“) or a class string like “"2xx"“. Anything outside the matched set is treated as a delivery failure.
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#headers ⇒ Object
Returns the value of attribute headers.
-
#method ⇒ Object
Returns the value of attribute method.
-
#success_status ⇒ Object
Returns the value of attribute success_status.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ForwarderHttp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ForwarderHttp
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::ForwarderHttp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::ForwarderHttp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'method') self.method = attributes[:'method'] else self.method = 'POST' end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'headers') if (value = attributes[:'headers']).is_a?(Array) self.headers = value end end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'success_status') self.success_status = attributes[:'success_status'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
25 26 27 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 25 def body @body end |
#headers ⇒ Object
Returns the value of attribute headers.
23 24 25 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 23 def headers @headers end |
#method ⇒ Object
Returns the value of attribute method.
19 20 21 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 19 def method @method end |
#success_status ⇒ Object
Returns the value of attribute success_status.
27 28 29 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 27 def success_status @success_status end |
#url ⇒ Object
Returns the value of attribute url.
21 22 23 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 21 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 30 def self.attribute_map { :'method' => :'method', :'url' => :'url', :'headers' => :'headers', :'body' => :'body', :'success_status' => :'success_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 62 def self.openapi_nullable Set.new([ :'body', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 51 def self.openapi_types { :'method' => :'String', :'url' => :'String', :'headers' => :'Array<HttpHeader>', :'body' => :'String', :'success_status' => :'SuccessStatus' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && method == o.method && url == o.url && headers == o.headers && body == o.body && success_status == o.success_status end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 194 def hash [method, url, headers, body, success_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @url.to_s.length > 2048 invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2048.') end if @url.to_s.length < 1 invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.') end if !@body.nil? && @body.to_s.length > 65536 invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 65536.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 143 144 |
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/forwarder_http.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? return false if @url.to_s.length > 2048 return false if @url.to_s.length < 1 return false if !@body.nil? && @body.to_s.length > 65536 true end |