Class: SmplkitGeneratedClient::Audit::TestForwarderRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb

Overview

Plain-JSON body for the test_forwarder execute action. Mirrors the encrypted “ForwarderHttp“ shape with one addition — “timeout_ms“, capped server-side.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TestForwarderRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Audit::TestForwarderRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Audit::TestForwarderRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = 'POST'
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Array)
      self.headers = value
    end
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'success_status')
    self.success_status = attributes[:'success_status']
  end

  if attributes.key?(:'timeout_ms')
    self.timeout_ms = attributes[:'timeout_ms']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



25
26
27
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 25

def body
  @body
end

#headersObject

Returns the value of attribute headers.



23
24
25
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 23

def headers
  @headers
end

#methodObject

Returns the value of attribute method.



19
20
21
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 19

def method
  @method
end

#success_statusObject

Returns the value of attribute success_status.



27
28
29
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 27

def success_status
  @success_status
end

#timeout_msObject

Returns the value of attribute timeout_ms.



29
30
31
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 29

def timeout_ms
  @timeout_ms
end

#urlObject

Returns the value of attribute url.



21
22
23
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 21

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 32

def self.attribute_map
  {
    :'method' => :'method',
    :'url' => :'url',
    :'headers' => :'headers',
    :'body' => :'body',
    :'success_status' => :'success_status',
    :'timeout_ms' => :'timeout_ms'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 66

def self.openapi_nullable
  Set.new([
    :'body',
    :'timeout_ms'
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 54

def self.openapi_types
  {
    :'method' => :'String',
    :'url' => :'String',
    :'headers' => :'Array<HttpHeader>',
    :'body' => :'String',
    :'success_status' => :'SuccessStatus',
    :'timeout_ms' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      method == o.method &&
      url == o.url &&
      headers == o.headers &&
      body == o.body &&
      success_status == o.success_status &&
      timeout_ms == o.timeout_ms
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 228

def hash
  [method, url, headers, body, success_status, timeout_ms].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @url.to_s.length > 2048
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 2048.')
  end

  if @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be greater than or equal to 1.')
  end

  if !@body.nil? && @body.to_s.length > 65536
    invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 65536.')
  end

  if !@timeout_ms.nil? && @timeout_ms > 30000
    invalid_properties.push('invalid value for "timeout_ms", must be smaller than or equal to 30000.')
  end

  if !@timeout_ms.nil? && @timeout_ms < 1
    invalid_properties.push('invalid value for "timeout_ms", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
163
# File 'lib/smplkit/_generated/audit/lib/smplkit_audit_client/models/test_forwarder_request.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @url.nil?
  return false if @url.to_s.length > 2048
  return false if @url.to_s.length < 1
  return false if !@body.nil? && @body.to_s.length > 65536
  return false if !@timeout_ms.nil? && @timeout_ms > 30000
  return false if !@timeout_ms.nil? && @timeout_ms < 1
  true
end