Class: SmplkitGeneratedClient::Config::ConfigBulkItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb

Overview

One config declaration reported by an SDK during bulk registration. Each item declares an entire config from code — the config’s key, optional parent reference, and the items the calling code uses with their declared types, default values, and descriptions.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConfigBulkItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Config::ConfigBulkItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Config::ConfigBulkItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'parent')
    self.parent = attributes[:'parent']
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Hash)
      self.items = value
    end
  end

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end
end

Instance Attribute Details

#descriptionObject

Optional human-readable description of the config.



26
27
28
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 26

def description
  @description
end

#environmentObject

Environment reporting the declaration. Defaults to ‘unknown`.



38
39
40
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 38

def environment
  @environment
end

#idObject

Config key as declared in code. URL-safe and stable for the lifetime of the config.



20
21
22
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 20

def id
  @id
end

#itemsObject

Items declared by the SDK with their types, defaults, and descriptions. Used to populate items on a newly-discovered config; ignored on subsequent observations of an existing config.



32
33
34
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 32

def items
  @items
end

#nameObject

Display name. Defaults to a humanized version of the ‘id` when omitted.



23
24
25
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 23

def name
  @name
end

#parentObject

Parent config key. Used only when creating a new (discovered) config. Ignored on subsequent observations of an existing config — discovery never modifies parent on a config that already exists.



29
30
31
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 29

def parent
  @parent
end

#serviceObject

Service reporting the declaration. Defaults to ‘unknown`.



35
36
37
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 35

def service
  @service
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'parent' => :'parent',
    :'items' => :'items',
    :'service' => :'service',
    :'environment' => :'environment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
84
85
86
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 77

def self.openapi_nullable
  Set.new([
    :'name',
    :'description',
    :'parent',
    :'items',
    :'service',
    :'environment'
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 64

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'parent' => :'String',
    :'items' => :'Hash<String, ConfigItemDefinition>',
    :'service' => :'String',
    :'environment' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
191
192
193
194
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      parent == o.parent &&
      items == o.items &&
      service == o.service &&
      environment == o.environment
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 204

def hash
  [id, name, description, parent, items, service, environment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if !@description.nil? && @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_bulk_item.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if !@description.nil? && @description.to_s.length > 1000
  true
end