Class: SmplkitGeneratedClient::Config::ConfigItemDefinition
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Config::ConfigItemDefinition
- Defined in:
- lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb
Overview
Schema for a single config item. “value“ may be “None“ to represent a cleared (typed but unset) slot — e.g. after a type change that could not coerce the previous value. See ADR-024.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#type ⇒ Object
Returns the value of attribute type.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConfigItemDefinition
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConfigItemDefinition
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Config::ConfigItemDefinition` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Config::ConfigItemDefinition`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'description') self.description = attributes[:'description'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 23 def description @description end |
#type ⇒ Object
Returns the value of attribute type.
21 22 23 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 21 def type @type end |
#value ⇒ Object
Returns the value of attribute value.
19 20 21 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 19 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 48 def self.attribute_map { :'value' => :'value', :'type' => :'type', :'description' => :'description' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 76 def self.openapi_nullable Set.new([ :'value', :'type', :'description' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 67 def self.openapi_types { :'value' => :'Object', :'type' => :'String', :'description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && value == o.value && type == o.type && description == o.description end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 173 def hash [value, type, description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 120 121 122 123 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@description.nil? && @description.to_s.length > 1000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/models/config_item_definition.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["STRING", "NUMBER", "BOOLEAN", "JSON"]) return false unless type_validator.valid?(@type) return false if !@description.nil? && @description.to_s.length > 1000 true end |