Class: SmplkitGeneratedClient::Config::ConfigsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Config::ConfigsApi
- Defined in:
- lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_config(config_response, opts = {}) ⇒ ConfigResponse
Create Config Create a new configuration.
-
#create_config_with_http_info(config_response, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Create Config Create a new configuration.
-
#delete_config(id, opts = {}) ⇒ nil
Delete Config Delete a configuration by its key.
-
#delete_config_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Config Delete a configuration by its key.
-
#get_config(id, opts = {}) ⇒ ConfigResponse
Get Config Return a configuration by its key.
-
#get_config_with_http_info(id, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Get Config Return a configuration by its key.
-
#initialize(api_client = ApiClient.default) ⇒ ConfigsApi
constructor
A new instance of ConfigsApi.
-
#list_configs(opts = {}) ⇒ ConfigListResponse
List Configs List all configurations for the authenticated account.
-
#list_configs_with_http_info(opts = {}) ⇒ Array<(ConfigListResponse, Integer, Hash)>
List Configs List all configurations for the authenticated account.
-
#update_config(id, config_response, opts = {}) ⇒ ConfigResponse
Update Config Replace a configuration entirely.
-
#update_config_with_http_info(id, config_response, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Update Config Replace a configuration entirely.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConfigsApi
Returns a new instance of ConfigsApi.
19 20 21 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_config(config_response, opts = {}) ⇒ ConfigResponse
Create Config Create a new configuration. The caller provides the id (key) in the request body.
27 28 29 30 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 27 def create_config(config_response, opts = {}) data, _status_code, _headers = create_config_with_http_info(config_response, opts) data end |
#create_config_with_http_info(config_response, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Create Config Create a new configuration. The caller provides the id (key) in the request body.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 37 def create_config_with_http_info(config_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.create_config ...' end # verify the required parameter 'config_response' is set if @api_client.config.client_side_validation && config_response.nil? fail ArgumentError, "Missing the required parameter 'config_response' when calling ConfigsApi.create_config" end # resource path local_var_path = '/api/v1/configs' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(config_response) # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.create_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#create_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_config(id, opts = {}) ⇒ nil
Delete Config Delete a configuration by its key.
95 96 97 98 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 95 def delete_config(id, opts = {}) delete_config_with_http_info(id, opts) nil end |
#delete_config_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Config Delete a configuration by its key.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 105 def delete_config_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.delete_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.delete_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.delete_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#delete_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_config(id, opts = {}) ⇒ ConfigResponse
Get Config Return a configuration by its key.
156 157 158 159 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 156 def get_config(id, opts = {}) data, _status_code, _headers = get_config_with_http_info(id, opts) data end |
#get_config_with_http_info(id, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Get Config Return a configuration by its key.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 166 def get_config_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.get_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.get_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.get_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#get_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_configs(opts = {}) ⇒ ConfigListResponse
List Configs List all configurations for the authenticated account.
219 220 221 222 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 219 def list_configs(opts = {}) data, _status_code, _headers = list_configs_with_http_info(opts) data end |
#list_configs_with_http_info(opts = {}) ⇒ Array<(ConfigListResponse, Integer, Hash)>
List Configs List all configurations for the authenticated account.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 229 def list_configs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.list_configs ...' end # resource path local_var_path = '/api/v1/configs' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[parent]'] = opts[:'filter_parent'] if !opts[:'filter_parent'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ConfigListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.list_configs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#list_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_config(id, config_response, opts = {}) ⇒ ConfigResponse
Update Config Replace a configuration entirely.
280 281 282 283 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 280 def update_config(id, config_response, opts = {}) data, _status_code, _headers = update_config_with_http_info(id, config_response, opts) data end |
#update_config_with_http_info(id, config_response, opts = {}) ⇒ Array<(ConfigResponse, Integer, Hash)>
Update Config Replace a configuration entirely.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/smplkit/_generated/config/lib/smplkit_config_client/api/configs_api.rb', line 291 def update_config_with_http_info(id, config_response, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConfigsApi.update_config ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ConfigsApi.update_config" end # verify the required parameter 'config_response' is set if @api_client.config.client_side_validation && config_response.nil? fail ArgumentError, "Missing the required parameter 'config_response' when calling ConfigsApi.update_config" end # resource path local_var_path = '/api/v1/configs/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(config_response) # return_type return_type = opts[:debug_return_type] || 'ConfigResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"ConfigsApi.update_config", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConfigsApi#update_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |