Class: SmplkitGeneratedClient::Flags::Flag

Inherits:
ApiModelBase show all
Defined in:
lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Flag

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Flags::Flag` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Flags::Flag`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  else
    self.default = nil
  end

  if attributes.key?(:'values')
    if (value = attributes[:'values']).is_a?(Array)
      self.values = value
    end
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Hash)
      self.environments = value
    end
  end

  if attributes.key?(:'managed')
    self.managed = attributes[:'managed']
  end

  if attributes.key?(:'sources')
    if (value = attributes[:'sources']).is_a?(Array)
      self.sources = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 38

def created_at
  @created_at
end

#defaultObject

Returns the value of attribute default.



26
27
28
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 26

def default
  @default
end

#descriptionObject

Returns the value of attribute description.



21
22
23
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 21

def description
  @description
end

#environmentsObject

Returns the value of attribute environments.



31
32
33
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 31

def environments
  @environments
end

#managedObject

True if admin-managed, false if auto-discovered



34
35
36
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 34

def managed
  @managed
end

#nameObject

Human-readable display name



19
20
21
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 19

def name
  @name
end

#sourcesObject

Returns the value of attribute sources.



36
37
38
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 36

def sources
  @sources
end

#typeObject

Value type: STRING, BOOLEAN, NUMERIC, or JSON



24
25
26
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 24

def type
  @type
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 40

def updated_at
  @updated_at
end

#valuesObject

Ordered set of allowed values (constrained), or null (unconstrained)



29
30
31
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 29

def values
  @values
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 43

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'type' => :'type',
    :'default' => :'default',
    :'values' => :'values',
    :'environments' => :'environments',
    :'managed' => :'managed',
    :'sources' => :'sources',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 85

def self.openapi_nullable
  Set.new([
    :'description',
    :'default',
    :'values',
    :'managed',
    :'sources',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 69

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'type' => :'String',
    :'default' => :'Object',
    :'values' => :'Array<FlagValue>',
    :'environments' => :'Hash<String, FlagEnvironment>',
    :'managed' => :'Boolean',
    :'sources' => :'Array<Hash<String, Object>>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      type == o.type &&
      default == o.default &&
      values == o.values &&
      environments == o.environments &&
      managed == o.managed &&
      sources == o.sources &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 236

def hash
  [name, description, type, default, values, environments, managed, sources, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/models/flag.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @type.nil?
  true
end