Class: SmplkitGeneratedClient::Flags::FunctionsApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Flags::FunctionsApi
- Defined in:
- lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/functions_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ FunctionsApi
constructor
A new instance of FunctionsApi.
-
#remove_references(remove_references_request, opts = {}) ⇒ RemoveReferencesResultEnvelope
Execute Remove References Bulk-remove context references from flag rules.
-
#remove_references_with_http_info(remove_references_request, opts = {}) ⇒ Array<(RemoveReferencesResultEnvelope, Integer, Hash)>
Execute Remove References Bulk-remove context references from flag rules.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ FunctionsApi
Returns a new instance of FunctionsApi.
19 20 21 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/functions_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/functions_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#remove_references(remove_references_request, opts = {}) ⇒ RemoveReferencesResultEnvelope
Execute Remove References Bulk-remove context references from flag rules. Traverses every flag in the account, removes rules that reference the specified context, and emits a single flags_changed event when done.
27 28 29 30 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/functions_api.rb', line 27 def remove_references(remove_references_request, opts = {}) data, _status_code, _headers = remove_references_with_http_info(remove_references_request, opts) data end |
#remove_references_with_http_info(remove_references_request, opts = {}) ⇒ Array<(RemoveReferencesResultEnvelope, Integer, Hash)>
Execute Remove References Bulk-remove context references from flag rules. Traverses every flag in the account, removes rules that reference the specified context, and emits a single flags_changed event when done.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/smplkit/_generated/flags/lib/smplkit_flags_client/api/functions_api.rb', line 37 def remove_references_with_http_info(remove_references_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: FunctionsApi.remove_references ...' end # verify the required parameter 'remove_references_request' is set if @api_client.config.client_side_validation && remove_references_request.nil? fail ArgumentError, "Missing the required parameter 'remove_references_request' when calling FunctionsApi.remove_references" end # resource path local_var_path = '/api/v1/functions/remove_references/actions/execute' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(remove_references_request) # return_type return_type = opts[:debug_return_type] || 'RemoveReferencesResultEnvelope' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"FunctionsApi.remove_references", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: FunctionsApi#remove_references\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |