Class: SmplkitGeneratedClient::Logging::LogGroup

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LogGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Logging::LogGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Logging::LogGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'parent_id')
    self.parent_id = attributes[:'parent_id']
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Hash)
      self.environments = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



26
27
28
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 26

def created_at
  @created_at
end

#environmentsObject

Returns the value of attribute environments.



24
25
26
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 24

def environments
  @environments
end

#levelObject

Returns the value of attribute level.



20
21
22
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 20

def level
  @level
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 18

def name
  @name
end

#parent_idObject

Returns the value of attribute parent_id.



22
23
24
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 22

def parent_id
  @parent_id
end

#updated_atObject

Returns the value of attribute updated_at.



28
29
30
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 28

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 31

def self.attribute_map
  {
    :'name' => :'name',
    :'level' => :'level',
    :'parent_id' => :'parent_id',
    :'environments' => :'environments',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
72
73
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 65

def self.openapi_nullable
  Set.new([
    :'level',
    :'parent_id',
    :'environments',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 53

def self.openapi_types
  {
    :'name' => :'String',
    :'level' => :'String',
    :'parent_id' => :'String',
    :'environments' => :'Hash<String, Object>',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      level == o.level &&
      parent_id == o.parent_id &&
      environments == o.environments &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 195

def hash
  [name, level, parent_id, environments, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if !@level.nil? && @level.to_s.length > 10
    invalid_properties.push('invalid value for "level", the character length must be smaller than or equal to 10.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 224

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/log_group.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if !@level.nil? && @level.to_s.length > 10
  true
end