Class: SmplkitGeneratedClient::Logging::LoggerBulkItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- SmplkitGeneratedClient::Logging::LoggerBulkItem
- Defined in:
- lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb
Overview
One logger discovered by an SDK during a bulk registration call.
Instance Attribute Summary collapse
-
#environment ⇒ Object
Environment where the logger was observed.
-
#id ⇒ Object
Dot-separated logger key as the SDK saw it.
-
#level ⇒ Object
Level explicitly set on the logger by application code.
-
#resolved_level ⇒ Object
Effective level after framework inheritance.
-
#service ⇒ Object
Service name that observed the logger.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoggerBulkItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LoggerBulkItem
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Logging::LoggerBulkItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Logging::LoggerBulkItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'level') self.level = attributes[:'level'] end if attributes.key?(:'resolved_level') self.resolved_level = attributes[:'resolved_level'] end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end end |
Instance Attribute Details
#environment ⇒ Object
Environment where the logger was observed.
32 33 34 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 32 def environment @environment end |
#id ⇒ Object
Dot-separated logger key as the SDK saw it.
20 21 22 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 20 def id @id end |
#level ⇒ Object
Level explicitly set on the logger by application code. ‘null` when the level is inherited.
23 24 25 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 23 def level @level end |
#resolved_level ⇒ Object
Effective level after framework inheritance. SDKs should always report this; the server falls back to ‘level` when `resolved_level` is missing.
26 27 28 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 26 def resolved_level @resolved_level end |
#service ⇒ Object
Service name that observed the logger.
29 30 31 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 29 def service @service end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 35 def self.attribute_map { :'id' => :'id', :'level' => :'level', :'resolved_level' => :'resolved_level', :'service' => :'service', :'environment' => :'environment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 172 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 72 73 74 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 67 def self.openapi_nullable Set.new([ :'level', :'resolved_level', :'service', :'environment' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 56 def self.openapi_types { :'id' => :'String', :'level' => :'String', :'resolved_level' => :'String', :'service' => :'String', :'environment' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && level == o.level && resolved_level == o.resolved_level && service == o.service && environment == o.environment end |
#eql?(o) ⇒ Boolean
159 160 161 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 159 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
165 166 167 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 165 def hash [id, level, resolved_level, service, environment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 194 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
129 130 131 132 133 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 129 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? true end |