Class: SmplkitGeneratedClient::Logging::LoggerBulkItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoggerBulkItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Logging::LoggerBulkItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Logging::LoggerBulkItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'resolved_level')
    self.resolved_level = attributes[:'resolved_level']
  end

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end
end

Instance Attribute Details

#environmentObject

Environment where this logger was observed



31
32
33
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 31

def environment
  @environment
end

#idObject

Normalized logger name



19
20
21
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 19

def id
  @id
end

#levelObject

The explicitly-set level on this logger. Null if inherited.



22
23
24
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 22

def level
  @level
end

#resolved_levelObject

The effective level after framework inheritance. Never null in compliant SDKs.



25
26
27
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 25

def resolved_level
  @resolved_level
end

#serviceObject

Service name that discovered this logger



28
29
30
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 28

def service
  @service
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'level' => :'level',
    :'resolved_level' => :'resolved_level',
    :'service' => :'service',
    :'environment' => :'environment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
72
73
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 66

def self.openapi_nullable
  Set.new([
    :'level',
    :'resolved_level',
    :'service',
    :'environment'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'level' => :'String',
    :'resolved_level' => :'String',
    :'service' => :'String',
    :'environment' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      level == o.level &&
      resolved_level == o.resolved_level &&
      service == o.service &&
      environment == o.environment
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 164

def hash
  [id, level, resolved_level, service, environment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_bulk_item.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end