Class: SmplkitGeneratedClient::Logging::LoggerSource

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LoggerSource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SmplkitGeneratedClient::Logging::LoggerSource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SmplkitGeneratedClient::Logging::LoggerSource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'service')
    self.service = attributes[:'service']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'level')
    self.level = attributes[:'level']
  end

  if attributes.key?(:'resolved_level')
    self.resolved_level = attributes[:'resolved_level']
  end

  if attributes.key?(:'first_observed')
    self.first_observed = attributes[:'first_observed']
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



30
31
32
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 30

def created_at
  @created_at
end

#environmentObject

Returns the value of attribute environment.



20
21
22
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 20

def environment
  @environment
end

#first_observedObject

Returns the value of attribute first_observed.



26
27
28
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 26

def first_observed
  @first_observed
end

#last_seenObject

Returns the value of attribute last_seen.



28
29
30
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 28

def last_seen
  @last_seen
end

#levelObject

Returns the value of attribute level.



22
23
24
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 22

def level
  @level
end

#resolved_levelObject

Returns the value of attribute resolved_level.



24
25
26
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 24

def resolved_level
  @resolved_level
end

#serviceObject

Returns the value of attribute service.



18
19
20
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 18

def service
  @service
end

#updated_atObject

Returns the value of attribute updated_at.



32
33
34
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 32

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 35

def self.attribute_map
  {
    :'service' => :'service',
    :'environment' => :'environment',
    :'level' => :'level',
    :'resolved_level' => :'resolved_level',
    :'first_observed' => :'first_observed',
    :'last_seen' => :'last_seen',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
80
81
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 73

def self.openapi_nullable
  Set.new([
    :'level',
    :'first_observed',
    :'last_seen',
    :'created_at',
    :'updated_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 59

def self.openapi_types
  {
    :'service' => :'String',
    :'environment' => :'String',
    :'level' => :'String',
    :'resolved_level' => :'String',
    :'first_observed' => :'Time',
    :'last_seen' => :'Time',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 149

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      service == o.service &&
      environment == o.environment &&
      level == o.level &&
      resolved_level == o.resolved_level &&
      first_observed == o.first_observed &&
      last_seen == o.last_seen &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 170

def hash
  [service, environment, level, resolved_level, first_observed, last_seen, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/models/logger_source.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end