Class: SmplkitGeneratedClient::Logging::LoggerSourcesApi
- Inherits:
-
Object
- Object
- SmplkitGeneratedClient::Logging::LoggerSourcesApi
- Defined in:
- lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LoggerSourcesApi
constructor
A new instance of LoggerSourcesApi.
-
#list_all_logger_sources(opts = {}) ⇒ LoggerSourceListResponse
List All Logger Sources List all logger sources across all loggers.
-
#list_all_logger_sources_with_http_info(opts = {}) ⇒ Array<(LoggerSourceListResponse, Integer, Hash)>
List All Logger Sources List all logger sources across all loggers.
-
#list_logger_sources(id, opts = {}) ⇒ LoggerSourceListResponse
List Logger Sources List all sources (service/environment observations) for a specific logger.
-
#list_logger_sources_with_http_info(id, opts = {}) ⇒ Array<(LoggerSourceListResponse, Integer, Hash)>
List Logger Sources List all sources (service/environment observations) for a specific logger.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LoggerSourcesApi
Returns a new instance of LoggerSourcesApi.
19 20 21 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_all_logger_sources(opts = {}) ⇒ LoggerSourceListResponse
List All Logger Sources List all logger sources across all loggers. Optionally filter by environment or service.
28 29 30 31 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 28 def list_all_logger_sources(opts = {}) data, _status_code, _headers = list_all_logger_sources_with_http_info(opts) data end |
#list_all_logger_sources_with_http_info(opts = {}) ⇒ Array<(LoggerSourceListResponse, Integer, Hash)>
List All Logger Sources List all logger sources across all loggers. Optionally filter by environment or service.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 39 def list_all_logger_sources_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LoggerSourcesApi.list_all_logger_sources ...' end # resource path local_var_path = '/api/v1/logger_sources' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[environment]'] = opts[:'filter_environment'] if !opts[:'filter_environment'].nil? query_params[:'filter[service]'] = opts[:'filter_service'] if !opts[:'filter_service'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LoggerSourceListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"LoggerSourcesApi.list_all_logger_sources", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LoggerSourcesApi#list_all_logger_sources\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_logger_sources(id, opts = {}) ⇒ LoggerSourceListResponse
List Logger Sources List all sources (service/environment observations) for a specific logger.
90 91 92 93 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 90 def list_logger_sources(id, opts = {}) data, _status_code, _headers = list_logger_sources_with_http_info(id, opts) data end |
#list_logger_sources_with_http_info(id, opts = {}) ⇒ Array<(LoggerSourceListResponse, Integer, Hash)>
List Logger Sources List all sources (service/environment observations) for a specific logger.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/smplkit/_generated/logging/lib/smplkit_logging_client/api/logger_sources_api.rb', line 100 def list_logger_sources_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LoggerSourcesApi.list_logger_sources ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LoggerSourcesApi.list_logger_sources" end # resource path local_var_path = '/api/v1/loggers/{id}/sources'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LoggerSourceListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['HTTPBearer'] = opts.merge( :operation => :"LoggerSourcesApi.list_logger_sources", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LoggerSourcesApi#list_logger_sources\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |